//Sanford-Wang xsec fit for neutral kaon
//
//    This code is intended to generate weights for neutrinos originating from K0 decays
//    utilizing a Sanford-Wang fit of world data  
//    
//    A this code is adopted from the MiniBooNE flux paper and the MiniBooNE reweighting framework 
//    along with code written by Raquel Castillo, Zarko, MiniBooNE (Steve Brice and Mike S), and Athula 
//
//    Current person adding comments and functions is Joseph Zennamo (jaz8600@fnal.gov)
//

#include "larsim/EventWeight/Base/WeightCalcCreator.h"
#include "larsim/EventWeight/Base/WeightCalc.h"

#include "art/Framework/Services/Registry/ServiceHandle.h"
#include "art/Framework/Services/Optional/RandomNumberGenerator.h"
#include "CLHEP/Random/RandomEngine.h"
#include "CLHEP/Random/RandGaussQ.h"

#include "nusimdata/SimulationBase/MCFlux.h"
#include "nusimdata/SimulationBase/MCTruth.h"
#include "nusimdata/SimulationBase/GTruth.h"

#include <vector>
#include "TH1.h"
#include "TArrayD.h"
#include "TMatrixD.h"
#include "TRandom3.h"
#include "TLorentzVector.h"
#include <iostream>
#include "TFile.h"
#include "TTree.h"
#include <TROOT.h>
#include <TChain.h>

using namespace std;

namespace evwgh {
  class PrimaryHadronSanfordWangWeightCalc : public WeightCalc
  {
  public:
    PrimaryHadronSanfordWangWeightCalc();
    void Configure(fhicl::ParameterSet const& p);
    std::pair< bool, double > MiniBooNEWeightCalc(simb::MCFlux flux, std::vector<double> rand);
    std::pair< bool, double > MicroBooNEWeightCalc(simb::MCFlux flux, std::vector<double> rand);
    virtual std::vector<std::vector<double> > GetWeight(art::Event & e);
    std::vector< std::vector< double > > MiniBooNERandomNumbers(std::string);
    

  private:
    CLHEP::RandGaussQ *fGaussRandom;
    std::vector<double> ConvertToVector(TArrayD const* array);
    std::string fGenieModuleLabel;
    std::vector<std::string> fParameter_list;
    float fParameter_sigma;
    int fNmultisims;
    std::vector<int> fprimaryHad;
    std::string fWeightCalc;
    std::string ExternalDataInput;
    double fScaleFactor;
    TFile* file;
    std::vector< std::vector< double > > fWeightArray; 
    std::string fMode;
    std::vector<double> SWK0FitVal;
    TMatrixD* SWK0FitCov;    
    double fSeed;
    bool fUseMBRands;

     DECLARE_WEIGHTCALC(PrimaryHadronSanfordWangWeightCalc)
  };
  PrimaryHadronSanfordWangWeightCalc::PrimaryHadronSanfordWangWeightCalc()
  {
  }

  void PrimaryHadronSanfordWangWeightCalc::Configure(fhicl::ParameterSet const& p)
  {

    // Here we do all our fhicl file configureation
    fGenieModuleLabel= p.get< std::string > ("genie_module_label");
    fhicl::ParameterSet const &pset=p.get<fhicl::ParameterSet> (GetName());
    std::cout << pset.to_string() << std::endl;

    fParameter_list		=   pset.get<std::vector<std::string> >("parameter_list");
    fParameter_sigma		=   pset.get<float>("parameter_sigma");
    fNmultisims			=   pset.get<int>("number_of_multisims");
    fprimaryHad			=   pset.get< std::vector< int > >("PrimaryHadronGeantCode");
    std::string dataInput       =   pset.get< std::string >("ExternalData");
    fWeightCalc                 =   pset.get<std::string>("weight_calculator");
    fMode                       =   pset.get<std::string>("mode");
    fScaleFactor                =   pset.get<double>("scale_factor");
    fSeed                       =   pset.get<double>("random_seed");
    fUseMBRands                 =   pset.get<bool>("use_MiniBooNE_random_numbers");
    // Getting External Data:
    //   Now let's get the external data that we will need 
    //   to assess what the central value of the p+Be -> K0
    //   cross section is and then also what are reasonable 
    //   variations around that central value.
    //   First: Pull in the file
    cet::search_path sp("FW_SEARCH_PATH");
    std::string ExternalDataInput = sp.find_file(dataInput);
    file = new TFile(Form("%s",ExternalDataInput.c_str()));
    //  Second: Define what we want to gather from that file which is two fold
    std::vector< std::string > pname; // these are what we will extract from the file
    pname.resize(2); // there are two items

    // We want the parameterization of the Sanford-Wang fit and the covariance matrix
    // which characterizes the uncertainties and how they correlate across the parameterization
    pname[0] = "SW/K0s/SWK0sFitVal";
    pname[1] = "SW/K0s/SWK0sFitCov";
    TArrayD* SWK0FitValArray = (TArrayD*) file->Get(pname[0].c_str());
    //TArrayD is the most annoying format I have ever experienced so let's convert it to a vector
    SWK0FitVal = PrimaryHadronSanfordWangWeightCalc::ConvertToVector(SWK0FitValArray);    
    SWK0FitCov = (TMatrixD*) file->Get(pname[1].c_str());
    *(SWK0FitCov) *= fScaleFactor*fScaleFactor;
    std::cout << "Scale Factor being applied : " << fScaleFactor << std::endl; 

    // This is done but it is important to note that the parameterization maps such that 
    // SWK0FitVal[0] corresponds to the diagonal element SWK0FitCov[0][0]
    
    //Prepare random generator
    art::ServiceHandle<art::RandomNumberGenerator> rng;
    fGaussRandom = new CLHEP::RandGaussQ(rng->getEngine(GetName()));
    
    //
    //  This part is very important. You will need more than a single random number
    //  per event. In fact you will need per universe as many random numbers as there
    //  are rows in the covariance matrix. 
    //
    //  To properly perform Cholesky decomposition you'll use a correlated set of random
    //  numbers when creating the smeared cross section methods. Please see documentation
    //  in WeightCalc to help with this.
    //
    
    if(fUseMBRands){//fParameter_list
      fWeightArray = PrimaryHadronSanfordWangWeightCalc::MiniBooNERandomNumbers(fParameter_list.at(0));
    }//Use MiniBooNE Randoms
    else{
      fWeightArray.resize(2*fNmultisims);
      
      for (unsigned int i=0;i<fWeightArray.size();i++) {
	fWeightArray[i].resize(SWK0FitCov->GetNcols());      
	if (fMode.find("multisim") != std::string::npos ){
	  for(unsigned int j = 0; j < fWeightArray[i].size(); j++){
	    fWeightArray[i][j]=fGaussRandom->shoot(&rng->getEngine(GetName()),0,1.);
	  }
	}
	else{
	  std::fill(fWeightArray[i].begin(), fWeightArray[i].end(), 1.);
	}
      }//Iterate through random number array
    }//Use LArSoft Randoms 
 
  
 
  }
  std::vector<std::vector<double> > PrimaryHadronSanfordWangWeightCalc::GetWeight(art::Event & e)
  {

    //Collect the event's Flux information
    //     This specifically deals with the neutrino type and parentage
    art::Handle< std::vector<simb::MCFlux> > mcFluxHandle;
    e.getByLabel(fGenieModuleLabel,mcFluxHandle);
    std::vector<simb::MCFlux> const& fluxlist = *mcFluxHandle;

    
    //Collect event's MC truth information
    //  This specifically deals with the neutrino energy and 
    //  counting how many interactions there are per event 
    //  (neutrino counting is CRITICALLY important for applying the 
    //   correct weights and not ending up with unphysical values)
    art::Handle< std::vector<simb::MCTruth> > mctruthHandle;
    e.getByLabel(fGenieModuleLabel,mctruthHandle);
    std::vector<simb::MCTruth> const& mclist = *mctruthHandle;
    
    //Create a vector of weights for each neutrino 
    std::vector< std::vector<double> > weight;
    weight.resize(mclist.size());
       
    //If there aren't any neutrinos in the event then just return an empty weight vector
    if(mclist.size() == 0 || fluxlist.size() == 0){return weight;}

    // Let's start by iterating through each of the neutrino interactions 
    for(unsigned int inu = 0; inu < fluxlist.size(); inu++){
      // First let's check that the parent of the neutrino we are looking for is 
      //  the particle we intended it to be, if not set all weights to 1
      // 
      //  There are three types of particles we want to check:
      //  K0S, K0L, and K0 (specific PDG CODE)
      if (std::find(fprimaryHad.begin(), fprimaryHad.end(), abs(fluxlist[inu].ftptype))
	  == fprimaryHad.end()){	
	weight[inu].resize(fNmultisims);
	std::fill(weight[inu].begin(), weight[inu].end(), 1);
	continue; //now move on to the next neutrino
      }// Hadronic parent check
          
      //Let's make a weights based on the calculator you have requested 
      if(fMode.find("multisim") != std::string::npos){       
	for (unsigned int i = 0;  int(weight[inu].size()) < fNmultisims; i++) {
	  if(fWeightCalc.find("MicroBooNE") != std::string::npos){
	    
	    //
	    //This way we only have to call the WeightCalc once
	    // 
	    std::pair<bool, double> test_weight =
	      MicroBooNEWeightCalc(fluxlist[inu], fWeightArray[i]);
	    
	    if(test_weight.first){
	      weight[inu].push_back(test_weight.second);
	    }
	  }
	  if(fWeightCalc.find("MiniBooNE") != std::string::npos){

	    //
	    //This way we only have to call the WeightCalc once
	    // 
	    std::pair<bool, double> test_weight =
	      MiniBooNEWeightCalc(fluxlist[inu], fWeightArray[i]);
	    
	    if(test_weight.first){
	      weight[inu].push_back(test_weight.second);
	    }
	  }
	}//Iterate through the number of universes      
      } // make sure we are multisiming


    }//Iterating through each neutrino 
    
    return weight;
  }

  //////////////////////////////
  ////////       Auxilary Functions
  //////////////////////////////

  //// 
  //   Use the MiniBooNE Implementation to determine the weight 
  ////
  std::pair< bool, double> PrimaryHadronSanfordWangWeightCalc::MiniBooNEWeightCalc(simb::MCFlux flux, std::vector<double> rand){
    
    // We now know that we have the hadronic parent that we want so we need to
    // prepare the kinimatic information about the iteraction to go into the Sanford-Wang
    // calculation
    
    // Computations are based on MiniBooNE code that can be found here:
    // 
    //   http://cdcvs0.fnal.gov/cgi-bin/public-cvs/cvsweb-public.cgi/~checkout~/...
    //                            miniboone/AnalysisFramework/Utilities/src/PhysicsFunctions.F
    //
    //  Attributed author in MiniBooNE code is Mike Shaevitz 
    //
    //   Useful references:
    //       MiniBooNE Collaboration, PhysRevD.79.072002
    //
    
    // We need to guard against unphysical parameters 
    bool parameters_pass = true;

    // Get Neutrino Parent Kinimatics       
    double HadronMass;

    
    if(std::find(fprimaryHad.begin(), fprimaryHad.end(), 130) != fprimaryHad.end() ||
       std::find(fprimaryHad.begin(), fprimaryHad.end(), 310) != fprimaryHad.end() ||
       std::find(fprimaryHad.begin(), fprimaryHad.end(), 311) != fprimaryHad.end())
      { 
	HadronMass = 0.4976; //Neutral Kaon
      }
      else{ 
	throw art::Exception(art::errors::StdException)
	  << "Sanford-Wang is only configured for Netrual Kaons";
      }

      TLorentzVector HadronVec; 
      double HadronPx = flux.ftpx;
      double HadronPy = flux.ftpy;
      double HadronPz = flux.ftpz;
      double HadronE  = sqrt(HadronPx*HadronPx + 
			     HadronPy*HadronPy + 
			     HadronPz*HadronPz + 
			     HadronMass*HadronMass);
      HadronVec.SetPxPyPzE(HadronPx,HadronPy,HadronPz,HadronE);

      // Get Initial Proton Kinitmatics 
      //   CURRENTLY GSimple flux files drop information about 
      //   the initial state proton, but that this 
      TLorentzVector ProtonVec;
      double ProtonMass = 0.9382720;
      double ProtonPx = 0;
      double ProtonPy = 0;
      double ProtonPz = 8.89; //GeV
      double ProtonE  = sqrt(ProtonPx*ProtonPx +
                             ProtonPy*ProtonPy +
                             ProtonPz*ProtonPz +
                             ProtonMass*ProtonMass);
      ProtonVec.SetPxPyPzE(ProtonPx,ProtonPy,ProtonPz,ProtonE);
      
      // Define the central value cross section
      // Pull out the parameters for the Sanford-Wang Fit
      double c1 = SWK0FitVal.at(0);     
      double c2 = SWK0FitVal.at(1);     
      double c3 = SWK0FitVal.at(2);     
      double c4 = SWK0FitVal.at(3);     
      double c5 = SWK0FitVal.at(4);     
      double c6 = SWK0FitVal.at(5);     
      double c7 = SWK0FitVal.at(6);     
      double c8 = SWK0FitVal.at(7);     
      double c9 = SWK0FitVal.at(8);     



      //Sanford-Wang Parameterization 
      //  Eq 11 from PhysRevD.79.072002
      
      double CV = c1 * pow(HadronVec.P(), c2) * 
	(1. - HadronVec.P()/(ProtonVec.P() - c9)) *
	exp(-1. * c3 * pow(HadronVec.P(), c4) / pow(ProtonVec.P(), c5)) *
	exp(-1. * c6 * HadronVec.Theta() *(HadronVec.P() - c7 * ProtonVec.P() * pow(cos(HadronVec.Theta()), c8)));
      
      // Check taken from MiniBooNE code
      if(float(HadronVec.P()) > (float(ProtonVec.P()) - float(c9))){
	CV = 0;
      } 
           
      // Define the variations around that cross section
      //    To do this we will call the a function from WeightCalc
      //    that will generate a set of smeared parameters based 
      //    on the covariance matrix that we imported
      std::vector< double > SWK0FitSmeared = WeightCalc::MultiGaussianSmearing(SWK0FitVal, SWK0FitCov, rand);       
     
      // Pull out the smeared parameters for the Sanford-Wang Fit
      double smeared_c1 = SWK0FitSmeared.at(0);     
      double smeared_c2 = SWK0FitSmeared.at(1);     
      double smeared_c3 = SWK0FitSmeared.at(2);     
      double smeared_c4 = SWK0FitSmeared.at(3);     
      double smeared_c5 = SWK0FitSmeared.at(4);     
      double smeared_c6 = SWK0FitSmeared.at(5);     
      double smeared_c7 = SWK0FitSmeared.at(6);     
      double smeared_c8 = SWK0FitSmeared.at(7);     
      double smeared_c9 = SWK0FitSmeared.at(8);     

      /// Perform the MiniBooNE 
      if(smeared_c1 < 0 || 
	 smeared_c3 < 0 || 
	 smeared_c6 < 0){
	parameters_pass = false;	
      }

      double RW = smeared_c1 * pow(HadronVec.P(), smeared_c2) * 
	(1. - HadronVec.P()/(ProtonVec.P() - smeared_c9)) *
	exp(-1. * smeared_c3 * pow(HadronVec.P(), smeared_c4) / pow(ProtonVec.P(), smeared_c5)) *
	exp(-1. * smeared_c6 * HadronVec.Theta() *(HadronVec.P() - smeared_c7 * ProtonVec.P() * pow(cos(HadronVec.Theta()), smeared_c8)));

      // Check taken from MiniBooNE code
      if(float(HadronVec.P()) > (float(ProtonVec.P()) - float(smeared_c9))){
	RW = 0;
      } 
           
      double weight = 1; 

      if(RW < 0 || CV < 0){
	weight = 1;
      }
      else if(fabs(CV) < 1.e-12){
	weight = 1;
      }
      else{
	weight *= RW/CV;
      }

      if(weight < 0) weight = 0; 
      if(weight > 30) weight = 30;
      if(!(std::isfinite(weight))) weight = 30;//From MiniBooNE; in Fortran Nan > 30

      std::pair<bool, double> output(parameters_pass, weight);

      return output; 

  }// Done with the MiniBooNE function


  //// 
  //   Use the MicroBooNE Implementation to determine the weight 
  ////
  std::pair<bool, double> PrimaryHadronSanfordWangWeightCalc::MicroBooNEWeightCalc(simb::MCFlux flux, std::vector<double> rand){

    // 
    //  Largely built off the MiniBooNE code 
    //  but this is intended to expand beyond it
    //
    //  Edits from MiniBooNE code:
    //
    //  JZ (6/2017) : Remove max weight, set to max_limit of a double
    //  JZ (6/2017) : Changed guards on c9 to be double point precision 
    //   

    // We need to guard against unphysical parameters 
    bool parameters_pass = true;

    // Get Neutrino Parent Kinimatics       
    double HadronMass;

    
    if(std::find(fprimaryHad.begin(), fprimaryHad.end(), 130) != fprimaryHad.end() ||
       std::find(fprimaryHad.begin(), fprimaryHad.end(), 310) != fprimaryHad.end() ||
       std::find(fprimaryHad.begin(), fprimaryHad.end(), 311) != fprimaryHad.end())
      { 
	HadronMass = 0.4976; //Neutral Kaon
      }
      else{ 
	throw art::Exception(art::errors::StdException)
	  << "Sanford-Wang is only configured for Netrual Kaons";
      }

      TLorentzVector HadronVec; 
      double HadronPx = flux.ftpx;
      double HadronPy = flux.ftpy;
      double HadronPz = flux.ftpz;
      double HadronE  = sqrt(HadronPx*HadronPx + 
			     HadronPy*HadronPy + 
			     HadronPz*HadronPz + 
			     HadronMass*HadronMass);
      HadronVec.SetPxPyPzE(HadronPx,HadronPy,HadronPz,HadronE);

      // Get Initial Proton Kinitmatics 
      //   CURRENTLY GSimple flux files drop information about 
      //   the initial state proton, but that this 
      TLorentzVector ProtonVec;
      double ProtonMass = 0.9382720;
      double ProtonPx = 0;
      double ProtonPy = 0;
      double ProtonPz = 8.89; //GeV
      double ProtonE  = sqrt(ProtonPx*ProtonPx +
                             ProtonPy*ProtonPy +
                             ProtonPz*ProtonPz +
                             ProtonMass*ProtonMass);
      ProtonVec.SetPxPyPzE(ProtonPx,ProtonPy,ProtonPz,ProtonE);
      
      // Define the central value cross section
      // Pull out the parameters for the Sanford-Wang Fit
      double c1 = SWK0FitVal.at(0);     
      double c2 = SWK0FitVal.at(1);     
      double c3 = SWK0FitVal.at(2);     
      double c4 = SWK0FitVal.at(3);     
      double c5 = SWK0FitVal.at(4);     
      double c6 = SWK0FitVal.at(5);     
      double c7 = SWK0FitVal.at(6);     
      double c8 = SWK0FitVal.at(7);     
      double c9 = SWK0FitVal.at(8);     

      //Sanford-Wang Parameterization 
      //  Eq 11 from PhysRevD.79.072002
      
      double CV = c1 * pow(HadronVec.P(), c2) * 
	(1. - HadronVec.P()/(ProtonVec.P() - c9)) *
	exp(-1. * c3 * pow(HadronVec.P(), c4) / pow(ProtonVec.P(), c5)) *
	exp(-1. * c6 * HadronVec.Theta() *(HadronVec.P() - c7 * ProtonVec.P() * pow(cos(HadronVec.Theta()), c8)));
      
      // Check taken from MiniBooNE code
      if((HadronVec.P()) > ((ProtonVec.P()) - (c9))){
	CV = 0;
      } 
           
      // Define the variations around that cross section
      //    To do this we will call the a function from WeightCalc
      //    that will generate a set of smeared parameters based 
      //    on the covariance matrix that we imported
      std::vector< double > SWK0FitSmeared = WeightCalc::MultiGaussianSmearing(SWK0FitVal, SWK0FitCov, rand);       
     
      // Pull out the smeared parameters for the Sanford-Wang Fit
      double smeared_c1 = SWK0FitSmeared.at(0);     
      double smeared_c2 = SWK0FitSmeared.at(1);     
      double smeared_c3 = SWK0FitSmeared.at(2);     
      double smeared_c4 = SWK0FitSmeared.at(3);     
      double smeared_c5 = SWK0FitSmeared.at(4);     
      double smeared_c6 = SWK0FitSmeared.at(5);     
      double smeared_c7 = SWK0FitSmeared.at(6);     
      double smeared_c8 = SWK0FitSmeared.at(7);     
      double smeared_c9 = SWK0FitSmeared.at(8);     

      /// Perform the MiniBooNE 
      if(smeared_c1 < 0 || 
	 smeared_c3 < 0 || 
	 smeared_c6 < 0){
	parameters_pass = false;	
      }

      double RW = smeared_c1 * pow(HadronVec.P(), smeared_c2) * 
	(1. - HadronVec.P()/(ProtonVec.P() - smeared_c9)) *
	exp(-1. * smeared_c3 * pow(HadronVec.P(), smeared_c4) / pow(ProtonVec.P(), smeared_c5)) *
	exp(-1. * smeared_c6 * HadronVec.Theta() *(HadronVec.P() - smeared_c7 * ProtonVec.P() * pow(cos(HadronVec.Theta()), smeared_c8)));

      // Check taken from MiniBooNE code
      if((HadronVec.P()) > ((ProtonVec.P()) - (smeared_c9))){
	RW = 0;
      } 
           
      double weight = 1; 

      if(RW < 0 || CV < 0){
	weight = 1;
      }
      else if(fabs(CV) < 1.e-12){
	weight = 1;
      }
      else{
	weight *= RW/CV;
      }

      if(weight < 0) weight = 0; 
      if(weight > 30) weight = 30; 
      if(!(std::isfinite(weight))){
	std::cout << "SW : Failed to get a finite weight" << std::endl;      
	weight = 30;
      }

      std::pair<bool, double> output(parameters_pass, weight);

      return output; 

  }// Done with the MicroBooNE function


  //// 
  //  This converts TArrayD to std::vector< double > 
  ///
  std::vector<double> PrimaryHadronSanfordWangWeightCalc::ConvertToVector(TArrayD const* array) {
    std::vector<double> v(array->GetSize());
    std::copy(array->GetArray(), array->GetArray() + array->GetSize(),
	      v.begin());
    return v;
  } // ConvertToVector()

  std::vector< std::vector< double > > PrimaryHadronSanfordWangWeightCalc::MiniBooNERandomNumbers(std::string pdg){

    if(pdg.compare("kzero") == 0){	 
      return {{-1.437340, 1.323193, 0.408699, -0.867556, -0.074886, -0.515931, -0.572060, -1.334828, -0.026128},{0.343105, -0.976637, -1.015412, -0.086901, 0.155177, -0.666718, -0.298011, 0.602788, -0.816838},{0.905034, -1.030798, 0.838830, -0.383688, -0.463019, 0.380719, 0.190007, 0.262615, -1.697171},{0.615792, 0.580948, 1.633461, 0.429288, -0.125428, -1.276246, 1.133938, -2.317750, 0.655204},{1.267826, 0.488591, 0.740213, -0.442882, -1.155295, 0.015484, 0.335352, -0.820391, -0.199893},{-1.193179, -0.260409, -0.428826, -0.911052, -0.689242, 1.974791, 0.161770, -1.436288, 1.181314},{-0.070805, 0.235415, 1.740404, 0.195070, -2.267739, 1.909067, -0.613443, -0.241293, 0.917751},{0.850416, 2.487741, -1.302500, 0.249996, -0.243973, -0.952426, 0.351039, 0.110039, 1.553301},{-0.400225, -0.180670, -0.649865, 0.207352, -1.290830, -0.588772, -0.820727, -0.164918, 0.478025},{0.830526, 0.802872, 0.648252, 0.303375, 1.111031, 0.736029, 1.782041, -0.243970, -0.881365},{-0.020555, -1.468731, -1.523458, 0.484422, -0.415060, 0.995942, -1.583366, -1.196141, -1.588845},{0.266932, -0.764246, 0.116177, 1.686998, -0.343115, 0.441140, 1.066621, 0.630161, 0.199173},{-0.280400, 0.673835, 1.344262, 0.235496, 1.199849, -0.775336, 0.883662, -0.265713, -1.780538},{0.390019, 0.436200, -0.576080, -0.390121, -0.719481, -1.084821, 1.070460, -1.305243, -0.806469},{-0.425033, -1.308645, 1.966526, 1.296666, -0.899169, -0.203374, 1.177794, -0.507805, -0.795150},{1.885078, -0.353321, 1.312102, -0.252481, -0.225467, 0.070138, -0.380354, -0.137728, -0.399845},{-0.264291, 0.838923, 0.235416, -1.133707, 0.213524, -1.172183, 1.722320, 0.573305, 0.120314},{0.346970, 0.888785, 0.775123, 0.890622, -0.520917, -1.337899, 1.524773, 0.236323, 0.888313},{1.637699, -0.395382, 0.247994, 1.336844, -0.044716, 0.486931, 0.655765, -2.279215, -1.159984},{-0.637552, 0.809107, 0.133402, -0.447355, -2.184884, 0.538202, 1.381242, 2.603824, -0.691923},{0.898885, -0.942742, 0.318357, 0.631714, 1.229590, 2.251719, -0.222204, -0.024136, -2.136873},{1.386871, -0.756751, 0.897316, -0.845995, -0.818325, 0.246106, -0.350896, 0.928056, 1.057819},{1.112474, -0.638297, 1.313870, -0.660373, 0.508829, -0.154440, -0.149838, -0.155003, -0.148449},{0.397559, -1.528404, 1.600281, 0.418202, -1.508055, -0.963110, -1.122013, -1.062145, -0.217795},{0.113263, 1.989277, 0.726863, -0.470831, -0.633058, -0.394370, 0.292404, -1.394729, 0.676001},{-0.817533, 0.469188, 0.700319, 1.084211, 1.367455, 0.288197, 0.332078, -0.810425, -0.467438},{-0.953804, -0.751529, 0.531053, 0.132788, 1.325492, 0.613992, 1.051693, 0.817613, -0.060521},{0.448315, -0.640987, 1.804885, 1.476300, 0.686965, 1.863062, 0.384992, -1.303357, -2.143556},{0.537852, 0.157319, 0.034527, 0.315301, 0.569111, 0.840332, -2.307524, 1.355689, 1.320098},{0.491649, 1.405292, -0.786031, 0.602916, -1.324569, 1.162171, 0.399717, -0.153997, -0.267376},{-1.435333, -1.077072, 0.306372, 0.249059, 0.577897, -0.618298, 0.811689, 1.222818, -0.376090},{0.911542, -1.456368, 1.169291, 0.085645, -1.889469, -0.357685, 1.016384, 0.956261, 0.688209},{1.462854, 0.276520, 1.875365, -0.646507, 1.257878, -0.857410, -0.596516, -1.146121, 0.313857},{-0.362019, -1.503512, 1.407789, 1.119055, -0.834055, -1.603355, 0.257218, -0.341640, 1.917758},{0.678814, 0.216616, -0.399489, 0.445652, -0.927680, 0.456401, 1.213588, -0.232508, -0.395884},{-0.452783, 0.675749, -1.200834, 0.993392, -0.624034, -1.504505, 0.363128, -1.952846, 1.477820},{-0.929419, 0.093945, -1.406013, 1.090127, 1.348770, -1.025790, 2.757116, 0.670344, 0.440884},{-0.224487, 0.076500, -0.192885, -1.094402, 0.934301, 1.084995, -0.514679, -0.102803, -0.692944},{-0.289408, 0.789304, -1.117358, 0.658805, 0.695301, -2.110373, 0.871871, -0.955728, 0.041177},{-1.355479, -0.006434, -0.573694, -0.133886, 0.048810, -0.111051, 1.133011, 0.119498, -0.214512},{2.820703, 1.539867, -0.081085, -0.114417, -0.219734, -0.257407, 0.375405, -0.494147, -0.245004},{-0.443880, 0.464229, 0.467265, 0.184580, -2.236709, -0.421089, 0.641692, -1.842351, 2.901984},{1.337599, -0.660445, 0.149886, -0.230830, 0.140112, -1.137815, -0.198043, 1.971799, 0.555463},{1.414813, 0.311758, 0.311320, 0.184115, 0.404700, -0.715662, -1.084727, 0.711426, -0.651171},{1.297971, 0.694105, 0.841091, -0.922905, -1.384198, -0.494183, 0.632811, -1.164994, -0.603196},{1.351832, 1.588099, 0.008788, -0.733395, -0.068376, -1.312086, -1.585337, 2.297330, 1.734234},{-2.254714, 0.571788, 0.545543, 1.063609, 1.205068, -0.187890, 1.337953, 1.177596, -0.053119},{-0.551990, 0.724532, 0.941909, -0.426678, -0.047919, -0.797140, -1.034145, -0.991847, 0.023467},{-0.458946, 0.246632, -0.697637, 0.752544, -2.114821, 0.443304, -0.927119, -0.739975, -1.826481},{0.200788, 0.849949, 0.285718, 1.848017, -1.517473, 1.488615, 0.579346, -1.177334, -1.284764},{0.382333, -0.436968, -0.611156, -0.299910, 1.128661, -0.307323, 0.937030, 0.247257, 0.887637},{-0.206323, 1.799421, -1.186369, 1.027014, 1.643919, 0.515046, -1.985253, -0.393061, -0.420797},{-0.346770, -1.646664, 0.046155, -1.083998, -0.318845, 1.799377, -0.534365, 2.424550, -0.988854},{-0.946606, 1.774282, 0.893148, 1.883511, -2.034028, -1.574972, -0.762255, -0.580870, -1.634815},{-0.217231, -0.654213, 1.341467, 1.935317, -0.104643, 0.754638, 0.039325, -0.779863, -0.079866},{0.070439, -0.058801, 0.167978, -0.045405, 0.098008, -0.141860, -0.040996, -0.786347, 0.752300},{0.233075, -0.446455, 0.282403, 0.550392, -0.186755, -0.203873, -0.014323, -1.573202, 0.075931},{-1.520507, 0.186988, -1.107488, -0.685035, -1.179229, 0.278213, -0.477583, -0.273340, 0.108306},{-0.096726, 0.513212, -1.006809, -0.149048, 0.800865, 2.564965, 0.089094, 1.178471, -0.840550},{-0.523983, -0.824187, -1.278494, -1.508642, 0.181175, -0.548087, -0.068207, 0.416682, -1.016973},{1.163612, -0.769659, 0.358142, -1.742873, -1.646965, 0.029047, 0.722540, 0.006852, 0.746598},{0.688473, -1.224453, 0.553998, 0.806003, -0.055503, -0.056352, 0.074516, 1.286573, -0.123033},{0.195242, -0.837296, -0.214717, -0.141585, 1.701555, -0.675496, -0.020960, 1.370167, 0.277246},{-0.631036, 0.366292, -1.120294, -0.677617, 1.442982, -0.713654, -0.589007, 0.209046, -0.528657},{-2.336320, 1.092421, 1.124329, -0.642162, -0.905441, -1.170965, -0.527861, -0.877830, -0.434368},{1.892612, 0.267294, -0.294323, -0.780995, -0.412099, -0.743037, -0.760395, -1.472865, 0.100307},{-0.265737, 0.792963, 0.173405, 0.500423, -0.177741, 1.583926, 0.454527, 1.255840, 0.905065},{-0.310905, -0.883056, -1.449926, -0.549256, 0.189812, -0.078740, 0.585021, 0.015275, 0.878555},{-0.168606, 0.853463, -1.623849, -1.148754, 2.469347, 0.305944, 0.292013, 1.702902, 1.231589},{1.290151, -0.088165, -1.239704, -0.321262, -0.750616, -0.231599, -0.339107, -1.483674, -0.539005},{0.010405, 0.625306, -0.487708, 0.171337, -0.335039, 1.044390, -2.184460, -0.407144, -0.249493},{-0.618342, -0.143729, 0.225058, -1.236973, -0.263761, -1.574297, 0.577808, -0.388255, 0.640042},{-1.327115, 0.788179, -1.009854, 0.189336, 0.810327, 0.641693, -0.514877, 0.098004, 0.721897},{0.416419, 0.112387, 0.455828, 0.836973, 0.292130, 0.422218, 0.222961, 0.652796, -1.286570},{-0.765343, 0.499332, 1.807178, 0.215192, -0.038827, 0.204405, -0.142406, 0.027788, 0.457914},{-0.473140, 0.410970, 1.548072, -1.266303, -1.176473, -0.865977, -1.484740, 1.286709, 0.952209},{-0.587250, 0.108987, -0.234872, -1.471244, 1.397654, -0.838368, -0.159569, -0.156264, -0.388246},{0.146699, 0.233400, -0.245287, 1.686100, -0.090920, 0.827118, -1.728205, -1.009567, -0.132352},{0.775374, 0.015596, 0.421089, 0.502134, -0.066361, -1.898842, -0.313127, 1.583863, -0.007159},{-0.936608, 0.721345, 0.370751, 0.372371, -0.242480, 0.159960, -1.331223, -0.290953, -1.341833},{1.186679, 0.369195, 1.325763, 0.643004, -1.680748, 0.655562, -0.609685, 1.022839, 1.021803},{-0.551025, -0.902411, 1.238807, 1.626979, 0.693118, -0.379318, 1.115418, 0.307848, -0.184038},{-0.169499, 1.519264, -0.319412, 2.166723, -1.023751, 1.608375, -0.200780, -0.936667, 1.880423},{-0.644318, 2.541030, -0.574412, -0.765831, -1.238958, 0.308837, 1.523808, -0.691182, 0.129850},{2.133466, -1.948589, -0.166980, -1.088183, 0.399184, 1.601472, -0.656079, 0.116893, 0.354698},{-1.322216, 1.045437, 0.846344, 0.338416, 0.366142, -0.518141, 0.846637, -1.370957, -0.158724},{-0.421533, 0.966170, 0.747683, -0.664676, -0.118941, 0.204952, -0.278781, -0.270475, -0.052256},{-0.564228, 1.544938, 0.845653, 0.844685, 1.518870, 0.358715, -0.224684, 2.189635, -0.004642},{-0.127782, 1.528948, -0.825750, 0.200092, 0.419456, 0.693132, 1.369453, -0.558645, 0.067052},{-0.937213, 1.358080, -0.349759, 1.328245, -1.158491, 1.676101, -0.490813, -0.699143, -0.539214},{-0.660187, 3.050610, -0.569464, 1.605416, -1.636621, 0.377913, -1.359042, -2.243558, 1.012470},{-0.886550, -0.779940, -1.649744, -0.241519, -0.080184, -0.794036, 2.017895, 0.099795, -0.934777},{0.729703, 0.490091, -0.252445, 0.766011, 1.443639, -0.821226, -0.361237, 0.461453, 0.559149},{0.946874, -1.296131, 0.657637, 0.184503, 0.390652, -0.420069, 1.753312, 0.692819, 1.389236},{0.677678, -0.228671, -0.606447, 1.138633, 0.717548, 0.086817, -1.149434, 1.155365, 1.530162},{-1.495743, 0.816693, -2.020670, -0.553525, -0.480671, 0.130486, 0.059458, -0.823028, 0.369713},{0.247814, 0.180762, 1.230598, -0.001901, -0.491757, -0.163995, 0.400019, -1.136711, -0.063933},{-0.126028, 0.183421, -0.713827, -1.715513, -0.285097, 0.806628, 0.098128, 0.140309, -1.699579},{0.688766, 0.033062, -0.929596, 0.781018, 1.160844, 1.521070, 0.210359, -0.898959, -1.356377},{-0.748715, 0.040138, 1.428149, -1.146752, 0.313815, 0.893381, 1.055741, 4.075023, -1.283519},{-0.100450, -0.752282, -0.158726, 0.237804, 1.101714, 1.407828, -0.106414, -0.739228, 0.778419},{-1.597608, -0.295649, 0.778007, 1.037864, -2.859662, -0.300341, 1.114380, -0.108802, 0.347987},{1.354042, 1.999937, 0.514182, 0.296057, 2.282207, 1.307494, 0.855262, 0.270776, 1.471251},{-0.154101, 1.738664, -2.440923, 0.754457, 0.175802, 0.845452, -1.784483, 0.260300, 0.789576},{-0.365032, -0.620749, -0.539270, 0.943737, 0.304530, 0.903852, 0.526396, 0.943035, 0.853587},{-0.526798, -0.234958, -0.063702, -0.946972, 1.221041, 1.395118, 0.675227, 0.698123, 0.305610},{0.022635, -0.980224, 0.831296, 0.997972, 0.899401, 0.084474, 0.409547, -0.513053, 1.664175},{0.493765, 0.155218, 0.899933, -0.344746, -0.747358, -0.644936, -0.107058, -0.573826, 0.160398},{-0.050900, -0.439649, -0.614151, -0.029980, 0.351187, -0.286203, -0.002900, -0.819045, -1.406554},{1.678567, -0.331862, 0.775784, 1.232582, -0.688857, 0.793090, -0.968025, 0.961508, -0.200758},{-2.328338, -0.696572, -0.416058, -0.119788, -0.292777, -0.801855, 1.010674, -0.142889, 1.490611},{-0.178411, -0.800872, -2.082811, 1.347422, 1.567619, 1.015352, -0.119390, -0.791319, -0.776831},{-1.061095, 0.196620, -0.081855, 0.562580, 1.538527, -1.074993, 1.671887, 1.564881, -1.086745},{0.081876, 0.603050, -0.789123, 0.114600, -0.638008, 0.319977, 0.065716, 1.422832, -1.111351},{2.566422, -0.230450, 0.529082, -1.111628, -1.022982, 0.623184, 1.017948, 0.491464, -1.062113},{0.329461, -0.782966, 0.405532, -0.621347, -0.596285, 0.205445, 0.413654, -0.760247, -0.103980},{0.818980, -0.656080, 0.402942, -1.726523, -0.000325, -0.311960, -0.794984, -0.152914, 0.603542},{1.594976, -0.731137, 0.095433, -0.471483, -0.102884, -1.261506, -0.189762, -1.473951, -0.208923},{-0.795915, 0.705019, -1.559093, -0.213391, -0.029901, -0.388410, 1.950891, -0.214387, -1.236146},{-0.877748, 1.618260, -1.068762, 0.144395, 0.803862, -0.788899, 1.233398, -0.413252, 0.733559},{0.718582, 0.209891, -0.806646, -0.925227, 0.107239, -1.883716, -0.794121, -0.582932, 0.563065},{0.010001, -1.210618, -0.103555, 0.550554, 0.457774, -0.929740, 1.357801, 0.460280, 0.960308},{-0.296490, -0.149660, -0.091516, -1.095860, -0.157278, -0.367756, -0.000565, 2.260801, -0.549436},{0.012644, -0.210821, 0.145786, -0.813503, -0.635931, 1.321916, -0.294082, -1.308018, 1.052032},{-0.470139, 2.214187, -1.571689, 1.154369, 0.308947, 0.007145, -0.230562, -0.364763, 1.592219},{0.597011, 1.202460, 0.584362, 1.668478, 0.553461, 0.056380, 0.230441, -1.274717, -0.814840},{-0.834089, 1.637412, 1.032137, -0.373535, -1.256351, -0.709826, 0.788416, 0.502443, -0.669046},{-0.638188, -1.251904, -0.872731, -0.564906, 0.273980, -0.288609, 0.146805, 0.476801, 1.140692},{-0.363212, 0.851439, 0.187746, 0.359119, -0.552795, -0.185760, 0.838707, 1.520434, -1.078321},{-0.106038, -0.495555, -2.332575, -0.392219, -1.652018, -0.735536, -1.256133, 0.341253, -1.035925},{0.784438, 0.313696, 0.749886, 0.882110, -0.730472, -0.565610, 2.755712, -0.122353, -0.412164},{-0.420299, 1.198774, -0.297228, 0.069373, -0.035894, -0.227224, 0.229779, 1.145631, -0.660864},{1.354555, -1.639354, 1.344164, -1.409352, -1.150775, 0.743544, 1.912941, -2.156421, 0.505129},{-0.580093, 0.179054, 0.782587, -0.627506, -0.601900, -0.500255, -2.172602, -2.089012, -0.939753},{1.133520, 0.825340, 1.098164, -0.445083, -0.304624, 1.494606, -1.583975, -0.059803, -1.145152},{0.147594, -1.020523, 0.623918, -0.392925, 0.787625, -1.419355, -0.664908, -0.246962, -0.650307},{-1.048857, 1.045832, 0.760130, -0.228114, -0.645781, 0.069737, -1.402930, -1.057633, 0.165217},{-1.289248, 0.318769, -0.219865, 0.768159, -0.753662, 0.543614, -1.439625, 0.910101, -1.128779},{-0.969560, 1.129048, -1.505660, 0.109729, -0.769124, 0.437603, 0.399101, -0.518968, 1.426437},{-1.719467, 0.721758, -0.781284, -1.468433, 1.736518, 0.481924, -0.892908, -0.376021, 0.173756},{-1.599531, -0.127220, 1.703618, 1.508107, 1.101652, 0.083879, -0.579747, -2.325179, -0.928445},{0.485201, 0.614622, 0.521898, -1.053388, 1.141896, -0.556108, 0.390417, 1.490247, -0.733217},{-0.964077, -0.660540, 0.789359, -0.145354, 0.391220, -0.558140, 0.003903, 1.042959, -0.205279},{-1.506847, -0.584772, -1.236092, 0.739686, -1.240411, -0.503343, 0.397774, 0.481266, 0.108737},{0.376657, -0.968203, -1.202727, -0.428273, -0.070368, 0.024313, -2.321069, -1.324190, -0.143859},{-2.184549, 0.483938, 1.782680, 1.157845, -1.563737, -0.204348, -1.426780, -0.149426, -0.090800},{-0.960374, 0.554274, -0.124189, -1.880894, 0.231138, 1.289442, 0.050700, 0.572600, -0.665579},{1.429688, 0.879877, -1.496677, 0.071033, -2.107259, 1.954833, -0.838797, 0.323929, -0.913582},{-1.753316, 0.309310, 0.020496, 1.074995, 0.258315, 0.827321, 0.951778, -0.947357, -0.054039},{0.428787, 1.552657, 0.062025, -0.722149, 1.066896, -1.171056, 1.179469, 0.519883, -0.467414},{0.121596, 0.160696, -1.153227, 0.718998, 0.307113, 0.123248, -0.288471, -0.471976, -0.879794},{1.173640, 0.623372, -0.530114, -0.570528, 0.543857, -1.530835, 0.587129, 0.268268, 1.493015},{-1.182819, -1.079468, 0.741515, -0.752025, -0.627411, -1.715993, -0.182629, -0.328465, 1.860247},{0.105331, 1.111018, -1.135720, -0.321029, -0.583628, -0.330913, -1.394778, -0.289123, 0.016276},{1.619778, -0.348743, 0.338897, -0.018503, -1.486269, -0.364504, 0.336647, 0.497046, -0.836849},{0.228142, 1.562197, -2.288161, 0.005343, -0.601287, -1.024257, -0.906804, -2.889652, 0.830968},{-0.251932, 0.180641, 0.159722, -0.430555, -0.501646, 0.889624, 0.996467, -0.062283, 0.209825},{-0.854906, -1.113356, -0.630630, -1.075332, 0.082713, 1.205498, -0.578125, 0.007770, -0.913450},{-1.817130, -1.119634, 0.531788, -1.106162, 0.020634, -0.783504, 0.828310, 0.628469, 0.666574},{-0.581836, 0.128890, -0.676318, -0.624444, -0.633200, -0.312270, 0.054968, 2.750564, 0.377027},{1.785221, 0.712234, -0.135565, -0.804327, -0.124415, -0.059542, -0.356352, 0.414926, -0.133608},{-1.267828, -1.121982, -0.309117, 0.312570, 1.373695, 0.019165, 0.980060, 0.058719, -0.317784},{2.192253, 1.107907, -0.674440, 0.004400, -0.755655, -1.158221, -1.076635, 0.749794, -1.252725},{1.681237, -1.303376, 0.332104, -0.621577, -0.492590, 0.161823, -1.114389, -1.103586, -0.829943},{-0.732967, -1.490593, 1.029964, 1.706500, 0.612123, -0.128552, -0.912562, 0.980999, 0.755311},{-0.774302, 0.591051, 0.569653, -0.709640, 0.104251, -1.315740, -0.157489, -1.219449, 1.776512},{2.461500, -1.006755, 0.095081, 1.877263, 1.359908, -0.688058, -0.452583, -0.196758, 0.244667},{0.490867, -0.142813, -0.560597, -0.729971, 1.643437, -1.691013, -1.386491, -1.261834, -1.080320},{0.314418, -0.582417, -0.154869, -0.281293, 0.736003, 0.541069, 0.394178, -0.405380, 0.183092},{1.248468, 0.039546, -1.569811, 0.206737, 1.047200, -0.584093, 1.189805, 0.941113, 1.423006},{-0.516595, 0.177145, 1.128219, 0.424152, 0.257064, -0.311829, -0.847265, -0.232257, 0.431785},{-0.040787, -0.657988, -1.467752, 0.819135, -0.394583, 2.362950, 0.366735, -1.619629, -0.568720},{0.823234, -1.377699, -1.194909, -1.824370, 0.177939, -1.856833, 0.107449, 0.322439, -3.159646},{0.554303, -3.275463, -1.963886, 0.951970, -0.522606, 0.961687, 0.479809, 0.431049, 0.151568},{0.046636, 0.156179, 2.480894, -1.797551, -1.112700, -1.600921, -0.020557, 2.200345, -1.934557},{0.378238, -0.915014, 0.363191, -1.368627, -0.405316, 0.456277, 0.452296, 1.237229, 0.061858},{-0.068746, -2.030248, -0.225123, -0.252604, -0.087091, -1.861109, 0.059015, -0.294638, 0.619147},{-0.589945, -0.528604, 0.284486, -0.611519, 1.252875, 0.008120, 0.493433, 0.327743, 2.603349},{1.248338, -2.070992, 0.891235, 1.152366, 1.819221, -1.338712, -0.346030, 0.433817, -0.230877},{-0.125829, 1.503450, 0.692286, -1.641983, -1.563310, -0.071671, 1.051412, -0.868339, 0.397258},{1.562960, 0.401423, 0.113015, -0.194298, 0.819705, -0.702903, 0.660987, -0.380485, 0.029751},{0.333608, -0.568666, 0.477811, 1.628551, -0.807340, 0.149733, 0.784360, 1.350214, 1.546425},{-0.680558, 0.292893, -0.369540, 0.448398, 0.457612, -0.052714, 0.316098, 0.744452, 2.614801},{1.462865, 1.073627, 0.430413, -1.085352, 1.707805, -1.357988, 1.117427, -2.254739, 0.782811},{0.101880, -1.315585, 0.756374, 1.069713, 1.375897, 0.171740, -0.386701, 0.270070, 2.725583},{0.171832, -0.791464, 0.442151, -0.335978, 1.368554, 0.661143, -0.266250, 0.765165, 0.201128},{2.078710, -0.190485, 0.513366, -1.784835, 1.383760, -0.464918, 1.048318, -1.258927, -1.199652},{-0.757817, -0.795011, 0.458300, -0.223437, -0.462744, 1.673288, -0.786580, -0.971750, 1.258222},{0.406706, -0.827293, 0.121666, 0.329808, 2.493790, -0.135944, 0.157375, 1.758809, 0.402458},{-1.484599, -0.366217, -0.272202, -1.688341, 0.574432, 0.292708, 0.295786, 0.988290, -1.004598},{-1.029798, 0.277664, 0.591803, -1.317384, 1.388024, 0.125164, -0.191844, -0.275075, -0.736183},{-0.577161, 0.633253, -0.766699, 0.691809, -1.032965, -0.962232, 0.103770, 0.474058, 0.135769},{0.985374, 0.393373, 0.443797, 0.876845, -1.202730, 0.822156, 1.460602, -1.250695, -0.015643},{-0.188457, -0.663533, 0.225428, -0.557173, 0.210674, -1.325410, 1.130697, -0.106162, -0.823769},{-1.949229, -0.379904, -0.595799, -0.451048, -0.589803, -0.468681, 1.234120, 1.124848, 1.285002},{-0.710767, 0.982777, 0.792335, 0.665892, -0.675280, 0.207754, -1.889271, -0.038040, 0.169365},{0.624823, -0.938879, -0.475402, 0.977705, -0.113381, 1.031767, -0.972235, -0.725166, 0.726936},{-0.516470, 1.357203, -1.065187, 1.309934, -0.000218, 0.423173, 2.224866, 0.477376, 1.485955},{-0.769229, 1.084876, -0.918563, -0.304181, -0.374435, 0.258401, -1.376620, 0.518965, 0.516024},{0.534371, 1.251016, 0.120262, 0.972497, -0.700344, -0.246031, 0.905709, 0.371052, 0.764403},{0.365650, 0.261339, -1.181547, -0.610268, 1.187915, 0.400060, -0.785438, -0.009441, -0.536460},{-1.110427, 0.962511, -0.888757, -0.928169, 1.597528, -0.554633, -0.300176, 2.780197, -0.863026},{-0.812074, -1.050994, -1.104275, -0.182327, -0.044469, 0.038725, -0.308758, 0.273658, -0.341298},{-0.489186, -1.797517, 2.151086, -0.321970, -1.570742, 0.570523, 0.684373, 0.234592, -0.739815},{-0.369115, 1.924760, -1.389660, -0.849368, 0.672399, -0.746600, -1.198999, -0.278724, -0.453608},{0.294596, 0.311427, 1.900732, -0.777245, 0.538627, 0.362378, -1.439994, -0.335234, -1.264001},{-0.614550, 0.179372, -0.383796, 0.606245, -0.119868, 0.439731, 0.691093, -0.815543, 0.494515},{0.597278, -0.108272, 0.991812, 0.831194, -0.761462, 0.780067, 1.284604, 0.342723, -0.607189},{0.973430, 0.563168, -1.024173, -0.343914, -1.677259, 0.906720, -2.708318, 0.129764, -0.818044},{-0.442941, -0.243486, 0.559040, -2.147909, 1.388319, -0.418823, 0.992427, -1.350963, -0.900861},{0.731245, 0.991231, -0.489796, 0.485220, 1.212711, -0.013645, 0.265795, 0.127147, 0.270546},{1.283859, 0.641202, -0.464702, 0.589305, -0.626665, 0.326099, -1.079515, -0.203334, 1.664125},{-0.081605, 0.127707, 1.054470, 1.838668, 0.538828, -0.448080, 0.595231, -0.408645, -0.720263},{-0.287141, -0.865156, 0.749186, -0.424346, 0.279049, -0.451138, 0.664357, 1.335453, -1.999876},{-1.216957, 1.841036, 0.946178, -0.150603, -1.250231, 0.419350, -0.384267, 1.141956, -1.747511},{-0.393711, -0.539129, 0.771798, 0.240080, 1.005152, -0.284645, 1.595128, 0.688430, -0.168067},{-1.579140, 0.297977, -1.540694, -0.828807, 0.625716, -2.234320, -1.166286, -0.194899, 2.809067},{-0.110923, 0.450073, 0.036619, -0.220186, 1.159367, 0.805472, 2.477329, -1.804637, -2.735717},{1.046481, 1.157949, -0.786750, 0.737843, 0.837884, 0.362811, 1.534703, -0.717452, -0.449500},{0.436428, 0.863031, -1.708274, 0.497274, -1.789873, 0.035456, -0.548562, 0.393710, 0.505164},{0.196504, 2.133324, -1.905908, -0.019043, 1.163507, -1.389045, -0.090826, -0.698905, 0.201478},{-0.444794, 0.886028, -0.222365, 0.257784, 1.012579, 0.576152, -1.629053, 1.730196, -2.390697},{1.168621, 0.042502, -0.333961, -0.215825, 0.326948, -1.403833, -1.218399, 1.027844, 0.163275},{0.351102, -0.337210, -1.126868, 0.868756, -0.450866, -0.137025, -1.440926, 0.831621, -2.171622},{0.637309, -0.088482, -0.215884, 0.246101, -0.285023, 0.516363, -1.114524, -1.477555, -0.459260},{0.917460, 0.322744, 0.584787, 1.632965, -0.413989, -0.561874, -0.039795, -0.834136, -1.718092},{-0.471168, -1.050514, -0.282501, 0.921292, -2.126940, 1.497644, -0.325450, 0.822186, -0.476824},{-0.750391, 1.753873, -0.191273, 0.279549, -1.572987, 0.535655, 0.261533, -0.613441, -0.113078},{0.113988, 0.988170, 0.776769, -0.306258, 0.690046, 1.741472, 0.639998, -1.426463, 0.663913},{-0.251537, 1.157832, -0.183767, 1.880835, 0.071172, -1.041400, -0.370219, -0.083247, -0.420447},{0.856228, -0.791362, 0.677855, 0.121722, -0.311606, 1.314241, -0.165026, 1.550072, -0.341995},{-0.784527, -0.808468, 1.415750, 0.540987, 0.575028, -0.676730, 0.290531, 2.003251, -0.755059},{-0.772384, -1.980470, 1.397344, -0.758763, -0.789504, -0.260104, 0.720404, 0.116525, 0.224139},{-2.117770, -1.295508, 0.282264, 0.852886, -0.290704, 0.432626, -0.386621, 0.929498, -1.125234},{-0.461948, -0.216706, 0.468042, 0.866698, -0.478385, 0.593609, -0.551949, -0.637502, -1.092041},{0.242387, -0.015035, -0.335408, -1.505013, 0.157422, 0.586568, -1.845837, 0.294407, -0.326039},{-1.295676, -0.480608, -0.139774, 0.006064, -0.245136, 1.645305, -1.507326, -0.873987, 0.907036},{-1.056744, 1.208162, 0.137838, -0.038795, 0.413284, -1.395549, -0.964397, 0.066957, 0.812514},{-0.694401, -0.069633, -0.764141, -1.315601, -0.753554, -2.421782, 0.334464, 1.307064, -1.160064},{-0.563519, 0.160874, -0.485771, -0.447690, 1.312574, -1.020942, 0.674093, -0.930693, 1.244171},{0.239177, -0.788177, -0.920344, 0.107394, 1.126493, 0.012415, -1.805338, 0.724381, -1.100167},{1.365373, 0.398974, 0.431421, -0.230587, 0.311964, 1.889188, -0.496741, 0.751972, -0.400872},{-0.753001, 0.830936, 0.798475, -0.262400, 1.249901, -0.912477, -0.296467, -0.510363, 0.053079},{0.232274, 0.114389, 0.021907, 1.400295, 0.351928, 0.238389, 1.153986, 1.090351, -0.156914},{-0.978729, 0.843451, 0.986609, -0.726659, 0.365349, 0.677109, -0.563850, -1.735929, -0.178361},{0.625127, -0.888736, -0.698177, 0.264070, 1.301537, 0.680252, -0.431877, -0.282452, -0.951008},{0.044310, 0.636238, 0.398305, -0.532797, -1.080576, -1.916624, -0.448317, -0.378738, -0.181686},{1.039324, -0.110961, -0.739281, 1.106805, -0.023573, -0.287554, -1.392285, -0.000992, 0.878004},{0.684392, -0.274973, 1.297384, -0.262342, 1.000514, -0.499367, 1.407082, 1.122790, 1.072349},{-1.814378, 0.100327, -0.542487, -0.694338, 0.090134, -0.165972, 0.377104, 0.593752, 2.404988},{-0.015507, 1.088170, -0.680871, -1.503617, -2.311454, 0.820555, 1.237132, -0.230129, -0.729671},{-0.402599, -0.447824, 1.929487, -1.671907, -0.033666, 2.217165, 0.603348, -0.678156, 0.649603},{1.029733, -1.941782, 0.529902, -1.704909, -1.797560, 0.312139, 0.571313, 0.564658, 0.422601},{-0.466415, 0.314101, 0.684146, 0.857801, 0.657756, 1.913555, -2.007010, 0.372011, -0.657580},{-1.402430, 1.169603, -2.039594, 0.069243, 0.173172, 1.178178, 1.723056, 0.482817, -0.439187},{2.207492, -0.204129, -0.707851, 0.152612, 1.414659, 2.311264, 0.077741, 0.776783, -0.395144},{0.872464, -1.073436, 1.358450, -0.152243, 1.915511, 0.768506, 1.714165, 0.035672, -1.965181},{-1.177352, 0.792548, -0.166843, -1.247743, -0.576057, -1.413055, 0.002432, 1.158411, -1.256209},{-0.755105, -0.083083, -0.856518, 1.028551, -1.172213, -1.310861, -0.776182, -0.541282, -0.210611},{2.332574, 1.851867, 0.960030, 1.055180, -0.131340, 0.924086, -1.362684, -0.706502, -0.015949},{-0.519019, -2.256032, -0.755989, -1.282224, 0.032735, 0.372794, 1.170891, 0.116439, 1.387769},{0.372661, 1.069414, -0.908091, 0.187901, -1.486208, -0.313226, -0.853804, -1.505007, 2.160935},{0.357670, -1.403184, -0.253297, 1.030129, 0.192882, -0.703412, -0.775604, -1.367810, 0.703243},{1.885248, -1.409315, -1.467774, -0.992747, 1.291833, -1.623939, 2.062594, 2.148181, 0.305524},{1.307819, 0.548401, -0.520399, -0.696697, -2.423201, 0.619943, 0.416567, -0.313810, 0.405571},{0.157889, 1.022652, -0.761348, -0.516346, 0.597924, -2.085313, -1.392454, -0.135629, 1.318048},{-0.278826, 1.095057, 1.482504, -0.781129, -1.140095, -0.397634, 1.101956, -1.179385, -1.281704},{-0.593212, 1.275020, 0.637967, 0.595690, -1.088192, -1.047602, 0.393253, 1.156199, -0.528772},{0.030627, 0.385349, 1.410249, -0.020531, -1.111155, 0.133616, 0.979279, 0.358100, 0.149998},{-1.806789, -0.560866, 1.457178, -0.664061, -1.166272, -1.680773, -1.054556, -1.472453, -0.294264},{0.068882, 0.809182, -0.262408, -1.052220, 0.645292, 1.536139, 0.166669, -1.073138, -0.789089},{0.789730, -1.263212, 0.735403, 1.551891, -1.124195, 0.327097, 1.555060, -1.690117, -0.149483},{-1.534959, 0.284530, 0.789907, -0.967351, -0.484843, -0.272746, -1.285299, -1.016945, 1.123589},{-0.460902, -2.026760, 0.016465, -0.211570, 1.333300, 0.693460, -1.467856, 2.178521, 0.842852},{0.451946, 0.534534, -0.261937, 0.281552, 0.497880, -1.568382, 0.018838, 1.514237, 0.230867},{-1.659624, -1.370961, 1.395331, 0.534499, 0.436522, -0.372964, -0.056696, -0.501964, -0.345844},{-1.174734, 0.570284, -0.954564, -0.368870, 1.426517, -0.795880, 0.512244, 0.728489, -0.974642},{0.407965, 0.075374, -0.308786, -0.104307, -0.920449, 0.171511, 0.515418, -1.346815, 1.424652},{-0.820895, 2.136152, 0.419028, 1.501877, -1.213271, -1.474226, 0.670619, -0.870993, -0.128058},{-0.103159, 0.060758, 0.958635, 0.628421, -0.983667, 0.512413, -0.290467, -0.457477, -1.877357},{-0.920387, 0.739130, -1.464345, 0.516140, 0.929185, 0.252508, 0.073465, 0.925309, 0.138181},{-2.619693, -0.320976, -0.014459, -0.554933, 0.058007, 1.228682, -1.009202, -1.242350, -0.279318},{-0.339947, -0.315374, 0.911807, -1.219645, -0.440187, 0.938856, 1.475742, 0.383952, 1.160707},{-0.875213, 2.376351, 0.541887, 0.168361, -1.278134, 0.951660, -0.863086, 0.761744, -0.570135},{1.161264, 0.656985, -0.255458, 0.208329, -1.820030, -0.334531, -2.519553, 1.332132, -0.172510},{-0.178498, 0.068879, 0.230589, -0.257187, -0.388589, -0.240396, -1.249082, -0.855682, -0.323810},{0.758108, -0.754774, -1.542332, -0.286229, -0.144010, -1.499631, -0.751475, -0.740405, -0.686002},{-2.190807, 0.879706, 1.306959, 0.026101, 0.422184, -0.461025, 0.619357, -0.280755, 0.924219},{-0.736726, 0.285153, 1.390867, 1.662173, -0.070966, 0.235058, 1.789502, -0.713631, -0.156502},{0.887852, -0.289916, -0.894346, -0.592485, 0.968233, -0.511502, -1.569278, 0.977845, 0.784975},{-0.067734, 0.058124, -0.553605, 0.546930, -1.446529, -1.100544, -0.928277, 0.242309, 0.316719},{0.827057, 0.449424, 0.708259, 0.082269, 0.192172, 0.835211, -1.049873, -0.037784, -0.517023},{0.157598, 1.016188, 1.388423, 0.357232, -1.470757, 0.055024, -0.255343, -0.133387, 0.465682},{0.719930, -0.019091, -1.172828, 0.477976, -0.901937, -1.388950, -0.614043, -0.443248, -0.616060},{1.336419, 0.992606, 1.667795, -1.133034, -0.280728, 0.113543, -0.551212, 0.290227, -0.808586},{-0.680737, 1.764083, -0.715048, 1.081869, 0.290755, -0.583677, -0.883064, -1.420143, -0.546223},{-0.581572, -1.127129, 0.564430, 1.343496, -1.609390, 0.133183, 0.229072, 1.188535, 1.870012},{0.023897, 0.467605, -0.093658, 0.802123, -0.488838, -0.064708, 0.132131, 0.610532, 0.085037},{-0.386414, 0.576488, -1.001059, -0.096493, -0.738221, 0.700079, -0.925171, -0.546331, 0.059728},{1.231169, 1.944198, -0.991655, 0.288357, -0.395964, 0.124973, -0.682960, -1.058633, -0.877556},{-0.653193, 0.313541, -0.190781, 1.349790, 2.438840, -0.464476, 0.103727, 0.935497, 0.474323},{1.016993, -0.290568, -0.745255, 0.403774, -0.172328, 0.533281, -0.156578, 1.099485, -1.491705},{-0.234658, -0.355930, 1.353355, -0.619800, 0.044680, -1.354366, -2.398606, 0.014229, -0.549389},{-1.052534, 0.623509, 1.569464, 1.470367, 0.712903, -0.035153, -2.419498, -1.067798, -0.765939},{-0.241291, 0.717557, 0.423014, -1.433409, 0.779103, -1.534707, 1.814882, -0.029916, -0.925252},{-0.065424, -0.213759, 0.105740, -0.355778, -1.652639, -1.197093, 0.474245, 0.329301, -0.785882},{-1.330134, 0.194971, -0.726226, 0.210396, -2.122685, -0.760630, 0.815472, 0.280402, -0.246284},{-0.342929, 0.571028, 1.163860, -0.410464, 1.100024, 1.170341, -2.385711, -1.193574, 1.465617},{1.245726, 2.260717, 0.263172, -0.598082, -0.882488, 1.563108, -0.477576, -0.360547, -1.321045},{0.050721, 0.130524, -0.707360, -1.879772, -1.302659, -0.808137, 1.483002, 1.238222, 0.092470},{-1.303125, -0.624953, -1.380168, 0.023023, -0.707447, -0.388025, -0.829841, -0.549293, -0.043584},{-0.071867, 0.871807, 0.610964, 0.717053, -0.620773, -0.366900, -0.140086, 0.536191, 1.788267},{0.415331, -0.627541, -0.736289, -0.310431, -0.222772, 1.198285, 0.609990, -0.132523, -1.521166},{0.557783, -0.207950, -0.401738, -0.047575, -0.270976, 1.249073, -0.878024, -1.081004, -0.360659},{0.474510, 0.804041, 0.987269, 1.200732, 1.308607, 0.510967, 0.633647, 0.150868, -0.078919},{-0.761371, -1.984377, 1.024826, -0.694918, -0.175495, 1.163595, 0.735482, -0.690356, 1.127403},{-0.940015, -0.714259, -0.120724, -0.872021, 1.135603, 0.367724, 0.103598, -1.724670, 0.391931},{-0.468320, -0.079535, 0.866998, -2.384305, -0.271987, 0.089544, -0.319114, -0.307625, 0.922346},{-2.378745, 0.028250, -0.832458, 0.247070, 0.711379, -0.316127, -0.860328, 0.964316, -0.799984},{0.631222, 0.134509, 1.378760, 1.158632, 0.138023, -0.247092, -1.045590, -0.509354, -0.550759},{-1.560896, 0.544109, 1.208848, 0.336029, -1.604542, 0.423132, 0.402335, 0.447817, 0.394358},{1.165570, 0.913025, 1.133518, -1.328886, 0.631846, 0.378060, -1.231414, -1.232390, 1.805233},{-1.674210, 1.116657, -0.958645, -1.251331, -0.738728, 0.448140, -1.402998, 0.941054, 0.720789},{-1.235216, -0.693367, 1.539012, -0.911865, 1.335204, -1.223710, 1.607417, 0.148850, -0.273509},{-1.202512, -1.386390, 1.655650, 0.781329, -0.079848, 0.727446, 0.292395, 1.010484, 0.945106},{1.956212, -0.098399, 1.160286, -0.525536, 0.918133, -0.572381, -0.359221, -1.081569, 1.038254},{-2.468388, 1.320331, -0.354816, 0.125459, 0.343272, -2.331211, 2.209539, 0.061721, 0.248821},{1.038987, -1.467143, 0.137786, 1.197658, -0.487184, -0.377367, -1.377323, 0.573656, 0.880235},{-0.613533, -0.588591, -0.885259, 1.047352, -0.026051, -1.037537, -0.129283, -0.752281, -0.192552},{-0.212105, 0.721923, -1.444862, -1.706346, 0.871077, -0.030171, -0.061804, -0.913128, -0.306367},{0.660563, 1.037179, 1.053315, 1.305278, 1.605426, 0.231077, 0.794551, 0.290606, 0.985706},{0.050227, -0.916137, -0.813748, 0.596044, 1.325660, 0.819953, 0.226617, 1.165415, -0.300821},{-1.168707, 1.160003, -0.201905, 0.629810, 0.577534, 0.094326, 0.150152, -0.722460, -1.544578},{0.736622, 0.508033, 1.338675, 0.814170, 0.525517, -0.051489, 0.280938, 2.200265, 0.552760},{-0.878616, 0.922623, -0.379361, -1.492076, 0.613291, -0.856580, 0.760361, 0.008275, 0.337929},{-0.189385, 0.057847, 0.106795, 0.742910, -0.071462, -0.744882, -0.289665, 0.188991, -0.096124},{1.210213, -0.489593, -2.049748, -1.140886, -0.096509, 0.886057, 1.062621, -0.030935, -0.526701},{0.229141, -1.128218, 0.350957, -0.242562, -1.935582, -0.653459, 1.634114, 0.436085, -0.875938},{0.966797, 0.366038, 2.283687, 0.570728, 0.822448, 1.351754, -0.703507, 0.758128, -1.671161},{1.809940, 0.056908, -0.457798, 0.256314, -0.200855, -1.133629, 1.911663, -0.222166, 0.703711},{1.612291, 0.008848, 0.275432, -0.389044, 1.505947, -0.978770, 1.487384, -0.647192, -0.583102},{0.125279, 0.228507, -1.471181, 1.547777, -0.035496, 0.797163, -1.268596, 0.637571, -0.620936},{-0.343378, -1.293724, -1.844182, 0.007623, -0.613665, -1.331902, -0.392364, 0.950829, 0.572758},{0.385978, 1.916597, 1.473614, -1.826727, 0.259151, -0.774929, -0.178050, -0.536410, 1.586699},{0.855903, 1.723629, 1.199271, 1.047137, -0.376459, -1.320195, 1.733543, -0.796685, -0.848474},{-0.374434, -1.287204, -0.453921, 2.192641, -1.061047, 0.164271, 1.063541, 2.796598, -1.387604},{-2.621348, 1.571384, 0.364477, 0.205339, -0.725410, 0.687576, -0.191992, -0.998645, -0.055864},{-0.667553, -0.491358, -0.931642, 0.015657, -1.084695, -0.715633, 0.754563, -1.259051, 0.095296},{0.657363, 0.624762, -1.143371, 0.582683, -1.308199, 2.345994, 1.898086, -0.545487, -0.694745},{0.384152, 0.105183, 0.528645, 0.758821, -0.690531, 0.802657, 0.948967, -0.468560, -0.463679},{1.578839, -0.919213, 0.532874, -0.132171, -0.383684, 0.123705, 0.011021, -0.010104, 0.106674},{2.097057, -0.698334, 1.291125, -0.312750, -0.012459, 1.145628, 1.020126, 0.765220, 1.738248},{0.427277, -0.435804, -0.070575, 1.910807, 1.260459, -0.792547, -0.785837, 0.796055, -0.678679},{1.634100, -1.362398, 0.271314, -0.821642, 0.431642, -0.169843, -0.242114, 0.582123, -1.219617},{-1.093993, 0.843640, -0.099367, 1.972735, 1.292071, -0.960169, -2.136863, 2.177599, -1.114287},{0.347886, 0.019726, 0.287724, -0.495419, 1.605133, 0.766566, -0.960414, -0.745908, 0.412047},{0.449087, 0.854720, -0.085085, 1.326060, -0.375227, -0.301741, 0.374229, 1.885607, 1.406900},{0.552715, 0.416041, -0.138637, -1.348545, -0.276848, -1.348408, -0.586829, -0.441651, 1.235200},{0.747737, -0.071964, -1.137433, 0.317353, 0.391276, 1.591304, 1.889448, 0.688168, -1.820629},{-0.562067, 0.521808, -0.148441, 0.785208, -0.910919, 0.007275, -1.457092, -0.941892, 0.617687},{-0.027080, -0.357866, 0.454977, 1.491584, 1.260447, -0.897032, -1.416084, 1.641982, 1.270538},{-0.041821, -0.950628, 0.204571, 0.817090, -0.791610, 0.901987, -0.553771, 1.264198, -0.000338},{-0.320972, -0.040090, 0.328208, 0.070755, 0.562751, 0.433897, -0.100737, 0.285883, 1.107908},{0.757461, -1.063737, -0.490565, 0.214315, -0.403146, 0.957102, 0.956284, -2.040824, -0.719726},{0.384304, 0.381597, -1.396464, -0.587941, -1.410797, -0.717370, -0.265558, 0.816233, 2.337188},{-0.444433, 1.520208, 1.537295, 0.458330, 1.062613, 0.666690, 0.365346, -0.278091, -0.520552},{-1.009168, 0.815787, -0.743964, 1.249294, 0.318884, 0.634472, -0.784221, 1.072589, -0.060351},{-1.080730, 0.813194, -0.187199, 1.017733, 0.380919, 0.044212, -1.577731, -0.542532, -2.252520},{-1.613354, -0.083557, -1.036340, -0.318867, -0.583558, 1.171755, -0.717435, -2.512199, 0.953977},{-1.135436, 0.575339, -0.058088, 1.235855, 0.450404, -0.530843, 0.658639, -0.260360, -0.092882},{-0.817127, -0.108407, 0.049247, 0.270442, -0.516699, -0.787280, 0.238748, -0.610775, 0.139952},{0.431074, 0.057628, -1.032721, 1.910686, 0.589896, 1.102782, 0.575732, 0.633791, -0.571084},{1.030870, 0.699080, 0.102763, 0.845186, 2.044786, -1.686182, -0.937496, 0.686984, 0.475245},{-1.136591, 0.476772, 1.265694, -2.211198, 1.659034, 1.747077, -1.328320, 0.072697, 1.253543},{-0.389441, 0.165987, 0.577073, 1.643033, -0.245035, 1.518236, 0.616996, 0.952145, -1.003106},{0.009908, 0.057290, -1.122544, -0.817925, 2.125986, 1.063513, 0.343381, 1.255238, 0.319169},{0.933451, 1.696335, 0.069718, -0.543360, 0.813483, 0.220848, -0.340361, -1.314930, 0.887687},{-0.274624, 0.624136, -0.421714, 1.479323, -0.324751, 1.223406, -0.538204, -0.556580, 0.537026},{0.612294, 0.087703, -2.010082, 1.446097, -1.069771, -0.191399, 0.676110, -0.276303, 0.312200},{-1.875108, 0.183467, 0.201510, 0.284583, -0.482730, 0.867030, 0.647377, 0.307241, -1.108835},{1.640235, 0.231691, 0.386147, 0.343807, -0.112239, -0.131563, 1.383880, 0.161376, -1.392512},{-0.113286, -0.390509, 1.090137, 1.663888, -0.470131, -0.277704, -0.736555, 2.150072, 0.190242},{2.055528, 0.091567, -0.984182, -0.815582, 1.259169, 0.695465, -0.611611, -0.328563, 0.926100},{-1.235499, -0.462922, -1.662512, 0.908933, 1.625084, -0.495256, 1.724610, 0.280246, -0.951719},{0.680468, 0.874865, 0.219324, 0.309704, 0.467942, -1.148877, -0.418521, -2.046852, 1.648430},{-0.275973, -1.158337, -1.313305, -1.117354, 0.609284, 0.367414, -0.338433, -2.051491, 1.219020},{-0.541129, 0.650711, -2.999989, 0.914210, -0.119368, 1.058092, 0.931013, 0.680644, -0.153908},{0.367198, -1.620924, -1.541879, 0.838817, -0.116558, -0.545382, -0.328205, -0.098502, -0.396780},{-1.250602, -0.445739, -1.690268, 1.023962, 0.731976, 0.470951, -1.165414, -0.298487, -1.156327},{-0.665347, -1.063988, -1.945870, 0.009010, 1.714568, -0.142847, 0.131151, -1.211703, 0.448749},{-0.942239, 0.116150, -0.481156, -0.375772, 0.911781, -0.903218, 3.114676, 0.834744, -0.613127},{-0.407530, -1.312610, 2.314041, 0.757884, -1.506877, -1.500878, -3.259471, -0.627905, 1.465253},{1.345079, -0.503551, -0.983155, 0.951387, -0.733730, 0.845764, 2.250201, -2.127210, 0.310862},{0.640761, -0.475252, 0.111332, 2.327005, -0.690712, -0.128189, -1.582997, 0.802473, 2.352067},{0.818129, -0.223346, 0.781833, -0.708515, 0.252487, 0.366673, 0.967190, -0.720991, -0.441106},{-0.447972, 0.417977, -0.402425, 0.490800, -0.183316, -0.207779, -0.052094, -0.714813, -0.399215},{0.931352, 0.741553, -0.563832, -1.018224, -1.230589, -0.873454, 0.393912, 1.816106, -0.985520},{0.680946, 0.213703, -1.204346, -0.079980, 0.698161, 0.373071, 0.607191, -0.159063, -0.317996},{0.016277, 2.342844, 0.216963, -0.569217, 1.056123, 1.591301, 0.269998, 0.987060, -0.331919},{-0.938538, 0.953994, -0.691266, -0.964265, 1.425568, 0.635673, -2.088246, -0.284148, 0.068031},{0.886051, -1.348759, -1.036093, -0.016382, 0.003527, -2.802382, -1.794114, 1.452578, -0.781550},{1.250323, 1.056488, 0.049474, 0.921290, -2.329986, -0.984529, -1.116084, 0.801872, -1.083095},{0.864351, 0.304451, -1.605572, -0.024388, -1.998527, 1.181961, 0.858420, 0.214256, 0.874799},{1.481971, 1.094974, 0.317645, -0.274846, -0.721364, 1.967334, -0.407978, 0.593962, -0.621765},{1.830117, -1.077077, -0.512848, 1.014130, 0.669292, -0.617452, -0.763919, -0.650325, 1.017321},{-0.366301, 0.991218, -0.420314, -0.064817, 0.461641, 0.404219, -0.580225, 2.217416, 0.402332},{-0.984165, -1.482503, -2.041560, -0.155636, 0.991969, -0.169414, -0.357885, 0.560073, 0.600742},{1.446807, 1.103951, -0.994433, -0.327137, 0.264395, 0.327114, -0.030767, 1.087595, -0.950542},{1.160721, -0.035693, 0.652700, -1.810156, -1.302437, -0.113697, -0.273555, -0.260323, 0.373382},{0.304071, -1.997298, 0.953426, -0.775138, 1.242147, 0.069114, 0.500134, 0.018147, -0.895538},{0.706631, 0.697552, 0.608542, 1.425218, 0.405820, -0.664279, 1.412371, -1.143710, -1.942132},{-1.030574, -0.234259, 0.854733, -1.425851, 0.363765, -0.023812, 0.544170, -0.861153, 1.557274},{1.012220, -0.172385, 0.264043, 2.041891, 0.878891, 0.085049, -1.383189, 1.096890, -3.229751},{-0.421192, -0.774674, 0.502706, 0.986842, -0.812234, 0.011225, -0.280518, 0.273852, 0.371765},{-0.630304, -0.057820, -0.558487, 0.537476, 0.179423, 0.106556, -0.194283, 0.060547, -0.524961},{-0.091606, 0.413523, -1.314287, -0.178564, 0.582982, -0.059725, -0.543835, -0.979780, -0.323623},{-0.261804, -1.728400, -1.186915, 0.670025, -0.907052, 0.038065, -0.930063, -0.067561, -0.014321},{0.936533, 1.307608, 0.119980, 0.818109, 0.963778, 0.669538, 1.584376, 0.208205, -0.563707},{-0.033734, 1.462325, -0.196561, 0.235116, 0.311410, -1.489431, 0.652864, -1.478052, -0.325285},{1.167825, 0.292097, 0.171498, -0.532825, 1.534627, -0.213938, 0.750307, -0.435243, -0.029246},{1.356377, 0.944493, 1.681217, -0.599286, -1.454814, 0.299820, 0.450681, 0.275986, -0.574436},{0.407048, 0.578769, 0.492571, -1.176286, -2.148256, -0.285267, -1.651532, 0.127254, 0.345018},{-0.834234, -0.169292, -2.134244, -1.043862, 2.613779, 0.740977, -0.854949, -1.615206, 0.338528},{0.714562, -0.793029, 0.741057, 0.777881, 0.507360, -0.231242, -0.260228, -0.345989, -1.668748},{-0.573168, -0.295650, -1.300439, 1.642843, -0.363618, 0.305657, 1.094722, 1.409744, 0.060689},{-1.018529, -0.414050, -1.134464, -1.079016, -1.555698, 0.129544, 1.105808, -1.098310, -1.027717},{-1.400192, 0.668612, -1.320452, -0.102601, 0.070230, -1.936560, 0.467196, 1.347980, 1.587954},{-0.251083, 1.370196, 1.341418, 0.119460, -0.805401, -1.531772, 1.345624, 0.113947, -1.083612},{-1.034901, 1.256107, -0.051249, -0.492275, 1.080142, -0.349055, 0.750529, -0.064071, 0.524953},{0.742761, -2.320993, 0.993782, -0.999341, 1.703200, 1.102098, 0.024988, 0.274988, -1.050903},{-0.419144, 0.756503, 0.756117, 0.091771, 1.126544, -0.987324, 1.026477, 1.314807, -1.930187},{0.887185, -0.753274, 0.739690, -0.492975, 0.047223, -0.721931, -0.747205, 1.659966, -0.784343},{-0.848937, -1.576472, 0.896426, 1.458843, -0.419077, 0.788673, -0.713913, 0.181159, 0.060905},{0.497774, 0.435156, -1.675835, -0.774221, 1.170750, 1.039188, -0.089953, 0.262030, -1.932318},{-0.785606, -0.235876, 0.709424, -1.408324, 0.667012, 0.102781, 0.093461, -0.701693, 0.056047},{0.336098, 0.245061, 0.410988, 0.621083, 0.311751, -0.207726, -1.299684, -0.909925, -0.329155},{2.394853, 0.863413, -1.399246, 1.463417, 0.410994, 0.774168, 0.778661, -0.067450, 0.215307},{-0.672005, 0.172606, -1.570444, -0.147124, 1.343633, -0.072879, 1.357019, 0.107380, 0.712069},{-0.992221, 1.383310, -0.148798, 0.386940, -2.269368, 1.814546, -0.239432, 0.692652, -1.770911},{0.533248, 0.369652, 2.398864, 1.346943, 1.099701, -1.166595, 0.211344, 0.044519, 1.413815},{0.440670, 1.541805, -0.038347, 0.073979, -0.842609, -0.164162, 1.119564, -0.115130, 0.050915},{-0.470975, 0.728538, -0.385939, 0.741671, -0.419997, 0.808762, 0.905786, 0.827510, 0.341616},{0.799223, -1.079310, -0.284585, -1.095588, 0.129824, -1.678263, -1.775951, 0.234047, -0.534236},{1.302983, 0.119836, 0.413493, 0.284198, 0.017348, -0.086119, 2.254576, 0.335345, -1.157247},{0.944157, 0.432003, 0.983695, -1.504420, -1.038904, 1.535934, -0.095958, 1.128316, 0.058456},{2.071009, -0.377124, -1.046931, -0.135455, -0.520167, -0.280035, -0.536854, 1.233531, -0.632492},{0.770034, -2.176804, 1.092489, 0.019343, -1.456741, -0.454052, 0.745457, 0.935457, -0.094947},{-0.621479, -1.316812, 0.121314, 0.904947, -1.471790, -0.210582, -2.586102, 0.256336, 0.065877},{-1.096886, -0.062031, -0.285989, -0.571159, -1.200652, 0.322869, -0.472804, 0.148925, 1.651962},{-0.734969, 2.343047, -1.104150, -0.741270, 0.616828, -1.520020, -0.213959, -0.856836, 1.095805},{0.569179, -2.067157, -0.734952, 0.646829, -0.661050, -0.006468, -0.191756, -0.936314, 1.097529},{-1.198083, -0.494815, -1.090077, 0.207080, -1.051175, 1.687655, 0.001674, -0.452377, -0.113146},{-0.290658, 0.521553, 1.345372, -0.430551, 1.263808, -2.093982, -0.821680, -0.307835, 0.572737},{0.455885, 2.992133, 0.032142, 1.327382, -0.491044, 0.096333, -1.763202, 2.201029, -1.375710},{0.362113, 1.072351, -1.932570, -0.330403, -2.061831, -0.017793, -0.940940, -0.792127, -0.591649},{1.323167, -0.803843, 1.306338, -0.369141, -0.724878, -0.075843, 0.220213, 0.521405, 0.459364},{-0.361724, -0.387471, -0.377986, 0.185626, -1.545655, 0.767495, 0.188596, 0.250414, 0.139323},{-0.285304, 0.379117, -1.627926, 0.937328, -0.203900, -1.306584, -0.295936, 0.823998, 0.860648},{-0.297529, 0.509990, 0.662092, -1.331846, -0.883426, 0.104029, -0.537262, -0.045781, 1.576206},{-0.591218, -0.036087, -1.676037, 0.069474, -0.016338, 0.371208, -2.250655, 0.856826, -0.890190},{-0.115021, -0.884627, -1.041792, -0.444853, 0.260707, -0.061067, -0.239523, 0.843461, -1.307439},{-0.738397, -1.276478, 0.510515, -0.811205, 1.565326, 0.278266, 2.388026, -0.518632, 0.339023},{-0.381337, -0.750362, -0.321986, -1.189339, -0.791713, -1.020440, 0.124427, -0.770437, 0.506638},{-0.969959, -0.481655, -1.482577, -0.254170, 0.356189, -1.858620, -0.102503, 0.779467, -0.825791},{-0.235848, 0.192988, -0.947167, -0.055764, -0.878532, 0.582834, -0.810800, 2.017365, -0.252615},{-0.049529, -0.801976, 0.324038, 1.161756, 1.005037, 1.875331, 1.914844, 0.541037, -0.515742},{0.361973, 0.528046, 0.952149, 1.118052, -0.385368, 1.216450, 0.516964, 1.624308, -1.992406},{-1.549272, -0.063419, 1.358960, 0.370098, 0.360182, -0.504910, 0.129997, 0.704964, -0.365226},{-0.358332, 0.653094, -0.236293, -0.553642, -1.666197, -1.502698, -0.575551, 0.085711, -0.054460},{0.940923, 1.838449, -0.168958, 0.707763, 2.452576, 0.407687, -0.422434, 0.277147, 1.115250},{1.526196, 0.595357, -0.303607, -2.125676, 1.177490, 1.603009, -0.061508, -0.541278, -0.170394},{0.375439, 0.494173, -0.731208, 0.009613, -1.440198, -0.287263, -0.183356, -0.461046, -0.372286},{-0.055774, 0.488516, -0.547831, -0.282550, 1.912649, 0.582353, -0.934834, -0.710461, -0.885196},{1.030900, 0.168165, -0.621790, 0.058979, 0.235751, -2.411716, -0.255169, 1.219097, 0.797003},{-0.473191, 0.405235, -0.025052, -1.002150, 0.111273, -0.391494, 0.269826, -0.422488, -0.485655},{0.693642, -0.755027, -0.593984, 0.127401, 2.193743, -0.859140, -1.373551, -0.715448, -2.005040},{-0.645047, 2.196382, 0.513812, -1.374418, -0.528907, 0.206967, -0.629157, 0.007829, -0.876214},{-0.918485, 0.605269, 0.336597, 0.087046, -0.069455, 0.447254, 1.252534, 1.200160, -1.421024},{-1.880160, 0.224033, -0.750404, -1.435726, 0.109829, -0.464147, 1.230515, 1.018160, 0.506330},{1.322578, -1.760701, -2.193707, -0.397127, -0.987803, -0.807725, -0.196062, -1.036763, -0.773631},{-0.341008, 1.396868, 0.280494, -1.058924, 1.853615, -0.543054, -0.556106, 0.372189, 0.817482},{0.704634, -1.229810, -0.501662, 0.939211, 1.411043, -0.514900, 0.354072, 1.220764, -0.833338},{-0.429924, 1.123381, -2.885991, -0.299069, 1.460093, 1.162525, 0.034509, 1.655536, -0.312779},{-0.560396, -1.011652, 0.457659, 0.362464, -0.495893, 0.729587, -0.090938, -1.129815, 0.152351},{0.057371, -1.923055, 1.016344, 0.733207, 0.459542, 0.007986, 0.898620, -1.597349, -0.067167},{-0.383536, -0.924059, 0.464764, 0.076884, 0.391920, -0.798095, -0.154395, -0.225585, 2.513019},{-0.122258, -0.447218, 0.875623, 0.357028, 2.603503, 0.429588, -0.538129, 0.658670, -0.201352},{-0.987422, 0.374805, -0.704009, 0.739274, 0.940119, -0.360919, 1.664721, -0.468628, -0.993049},{0.489609, 0.833176, -1.072180, 0.033698, -0.782502, -1.000617, 0.083747, 0.012883, 0.191942},{-0.495872, 1.041119, -0.396873, 0.721401, 0.165123, -1.485795, -1.087077, -1.903551, 0.318086},{-1.026455, -1.068847, 2.003934, -0.707140, 0.322906, -1.446712, -0.367967, -0.017577, -3.253305},{-0.015642, 2.526076, 0.988277, -0.661777, 0.823194, 0.329688, -0.666903, 1.051278, 0.077109},{-0.671963, 0.115154, 0.507778, 1.629197, -1.491009, -0.294870, -0.289793, -1.480729, -0.020787},{3.060055, -0.639642, -0.286890, 0.408992, -0.612650, 2.033606, -0.235152, 0.836670, -1.111625},{1.002200, -0.143991, 0.281900, 1.549119, -0.844713, 0.709603, 1.269129, 0.191363, -1.685917},{0.250560, -0.250338, -0.582948, 0.890581, 1.187669, -0.751845, -1.018575, 0.344017, -1.082777},{1.611967, 0.486349, 0.793312, 0.732833, -1.357974, 0.150097, 2.364433, -1.176499, 0.199267},{-1.879483, -0.514126, 0.172160, -0.876323, -0.584498, 1.363994, -0.096838, -0.059110, 0.588089},{-2.106671, -0.425249, 0.857311, 0.780806, 1.087780, 0.201032, 0.738514, 1.162094, -0.396711},{-0.188813, -1.283907, -0.437644, -0.890180, 0.514689, -0.847418, 0.271918, -3.453186, 0.843004},{-0.902588, -1.378278, -0.662883, 1.056886, -0.738146, 0.379523, 0.534355, -1.944133, -0.253037},{-0.294460, 0.012188, 0.327428, 0.105231, -0.817947, -0.164375, -0.335235, -0.005479, -0.404452},{-0.097884, 0.134746, -0.935017, -0.541517, 0.197961, -0.781446, 0.194859, 0.081389, -0.171538},{-0.611410, 1.485114, 0.932710, 0.650360, 0.753896, -1.474387, 0.712342, -0.104276, -0.736282},{1.725675, 1.333499, 2.516608, -1.158767, 2.872338, -0.766197, -0.172055, 0.050393, 0.022903},{-0.344009, -0.496428, 0.188928, -0.867952, 0.663753, 0.439580, -1.839577, -0.096978, -0.150913},{-0.700861, 0.191062, -0.606979, 0.606564, 1.364868, -0.082268, -0.692132, -1.103852, -1.446721},{0.737820, -0.185011, -1.466684, -0.258041, 0.852617, -0.195330, 0.406759, 0.006559, 0.238808},{-0.850797, 0.400879, -0.846850, -0.152936, -1.437079, 2.273481, -0.751406, -0.213546, 0.535297},{0.279725, 0.071361, 0.728393, 0.210057, -1.179703, -1.029992, -1.358873, 0.677249, 0.362209},{0.100525, 0.268756, 0.769846, 1.399028, -0.216311, -1.901204, -1.188746, -0.564721, 0.193058},{-2.228002, -1.099541, -1.096693, -0.205216, -0.424114, 1.063045, 1.138364, -0.084272, -1.207654},{-1.415381, 0.543874, -0.970461, 0.506351, -0.003518, 0.371711, -1.390293, -0.338855, 1.715677},{-0.540214, 0.311471, -1.529243, 2.311044, 0.298219, 0.525077, 1.534973, -1.499650, 0.156526},{1.009944, -1.702561, -0.752247, -1.817310, 0.083207, -0.119001, 0.944825, 2.474437, 0.705129},{0.900900, -0.825681, 0.706478, -0.769122, 0.519383, 1.624696, -0.457443, 0.556416, 0.646201},{2.029622, 0.078515, 1.549571, 0.239147, -0.193309, -0.486620, -1.708018, -0.762859, 1.594882},{0.487607, -0.388705, -0.995968, -2.505648, 1.045754, 0.110356, -1.050378, 0.322015, -0.175206},{0.784264, 0.036855, -0.128649, -0.133374, 1.622529, 0.223241, 0.237541, -0.672233, 1.225651},{-1.450034, 0.593548, -0.272122, -0.832634, 0.677845, 0.768767, 0.006235, 0.161758, -1.022690},{0.437236, -0.245777, 1.623148, 0.920735, -1.506871, -2.152520, -0.764412, -1.680219, -0.777994},{0.092858, -1.361762, 1.051092, -3.372047, -0.124856, -1.218768, -2.069522, -1.164249, -1.072973},{-0.111986, 0.192710, 1.153053, -0.172626, 1.127339, 1.719186, -0.184325, -0.914511, 0.588358},{1.635876, 0.389410, -0.795173, -0.616890, -0.945959, -0.729013, 0.980915, 2.504611, 0.183129},{-0.977591, -0.279280, -0.139874, -0.564411, 0.420699, -1.402743, -0.097328, 0.170643, -0.839857},{-1.200855, 0.436827, -0.350473, -1.218782, 0.573108, -1.088930, 0.571771, -1.275801, -0.467100},{1.201955, -0.683376, -0.047620, 0.035674, -0.551501, -0.278682, 2.071031, -1.763477, -0.431398},{-1.073370, -2.173816, -0.361308, -0.847695, 1.609083, 1.022906, 1.616641, -1.978035, 0.417340},{-1.090146, 0.037640, 0.181386, -0.473230, 1.659945, -0.578860, -1.500083, 1.180176, 1.584975},{1.790632, -0.327440, -0.430588, -0.713850, 0.165879, 0.125898, -0.058297, -0.651384, -0.842951},{-0.070667, -0.208574, 1.658617, 2.492712, 2.343639, 0.094854, 0.575498, 0.134464, -1.078596},{1.159869, -1.226544, -1.074865, 1.711568, 0.432745, 1.329300, -1.128709, 0.619433, 0.517870},{1.848730, 0.244317, -0.487552, 0.576402, 1.269906, -0.072286, 0.087085, 0.756826, 1.407878},{0.053579, 1.143001, 0.207523, 1.640671, 1.111846, 0.652814, -0.094083, 0.439439, -0.980726},{-0.026816, 0.164437, 0.312930, -1.004723, -2.066520, 0.536034, 1.974948, 0.750703, 0.517856},{0.740998, -0.665820, 0.739149, -0.318966, -2.501099, -1.057808, 0.262604, 1.627336, -1.146249},{0.483501, 1.325763, 1.467968, 0.912235, 0.362085, -0.612538, -0.586196, 0.354702, -0.203239},{0.271932, 1.206500, -0.522628, 1.012349, 1.937441, 0.291822, -1.247916, -0.722451, 0.332121},{-0.775358, 0.152329, -0.825240, 0.301543, -1.103788, 0.911476, -0.518016, 1.460822, 0.018906},{0.495017, 0.412747, -0.331860, -0.349785, -1.302704, 1.085025, 0.094922, -0.045101, -0.248245},{-0.526247, 0.119732, 0.549452, -0.270210, 0.113225, 0.073287, -0.150847, 0.727116, 0.291262},{-0.478845, -0.173658, 1.328517, 0.594282, 0.937827, -1.313602, -0.248419, 0.632832, 0.838326},{-0.274592, -0.996344, 0.159677, -0.437060, -1.018580, 0.565421, 0.064293, -0.934426, 0.650699},{-0.049556, -1.020319, 0.737161, 0.893639, -0.522582, -0.603976, 0.829719, -0.922558, 0.213419},{-0.657797, 0.179959, 0.484231, 0.354381, 0.045850, -0.594740, -0.225068, 0.006967, -0.037627},{0.813818, 0.329969, 0.729512, -2.333585, 0.061222, 0.016982, -0.522104, -0.296004, 0.867892},{0.493640, -1.222735, -1.538369, 0.505325, -1.376501, 0.645181, -1.816103, 0.174261, 0.581038},{-0.817058, -0.696129, -0.063842, 0.605965, -1.167056, 1.033966, -1.007871, -2.806911, -0.419877},{0.873482, -2.193680, 0.261422, -0.260988, -1.008570, -0.060995, -1.721809, 0.247228, 0.143501},{0.548103, 1.074620, -1.818456, 0.369634, -0.825945, 0.983921, -0.810260, 0.004392, -1.262288},{0.383472, -0.771136, -0.969849, 0.141219, -0.647064, -0.357073, 2.684356, -1.598084, 1.166465},{-0.746739, -0.902296, -1.098902, -0.309109, -0.437506, 0.085171, 1.723031, -1.034374, 1.447714},{0.016429, -0.625643, 0.681323, 0.581934, -1.811991, 0.136283, -1.259796, -1.250888, 0.359681},{-1.225633, 0.400591, -1.096496, -1.856235, -0.070412, -0.200677, 1.436831, 0.549195, 0.212687},{1.462394, -0.426632, -0.493826, 0.110404, 0.501351, -0.110146, -0.738548, 0.729103, -0.436808},{0.419303, -0.935798, -1.417122, 0.542083, -2.732192, 0.094778, -0.113194, 0.314385, 1.467273},{-2.193810, 1.575844, -0.647437, 0.419616, -0.124404, 0.140215, 1.539859, 0.526379, -1.530959},{0.657595, 0.347313, -1.246278, 1.403099, 2.286447, 0.059940, 0.300960, -0.062980, -0.715243},{1.591333, 1.156273, -0.543486, -0.608382, 1.053678, 0.064374, -0.501585, -0.946944, 0.166059},{0.281080, 0.165425, -0.575618, -0.469653, 0.582670, 1.012595, -0.482152, -0.559421, 0.341139},{-0.213510, 1.157906, 0.148952, 0.563075, -0.996812, 1.039283, -0.521861, -2.238467, -0.022890},{1.598792, 0.272689, -0.306986, 0.476107, 0.792104, 0.187634, -0.043458, -0.156928, 1.522405},{1.118815, 1.070016, -1.738058, -0.912841, -2.041591, 1.697572, 0.828493, -2.205380, 0.094597},{-0.764756, -0.267236, 0.113854, 3.125847, 0.264208, 1.745018, 0.618911, 1.416100, 0.118079},{-0.903748, -0.004953, 1.274205, -0.183448, 2.412893, 0.309007, 0.338792, 0.142614, -1.215186},{-1.125484, 1.097376, -0.429121, 0.499666, -0.437086, -1.333888, 0.850298, 1.622940, -0.710795},{-1.054028, 0.078822, -0.907402, -1.977707, 0.242645, 1.761231, -0.096940, 0.277124, 0.483858},{-0.331459, -1.541407, 0.342630, 0.223244, -0.911834, 1.439832, -0.100999, 0.966670, -1.065938},{2.260955, -0.779374, 1.084961, -2.113248, 0.601786, 0.222494, 1.927811, 0.635465, -1.014531},{-0.283643, 1.048752, 1.350011, 0.016757, -1.258899, -1.116933, -0.353411, -1.894217, 0.093266},{-1.338512, 1.206191, 0.275566, 0.399833, -0.360487, 0.607381, -1.038418, -1.583258, -0.042856},{0.973619, 0.426458, 0.589664, -0.896619, -0.931542, 2.141713, 1.110069, -0.584311, -0.380858},{0.735648, -2.043246, 0.013104, -0.231215, 0.620754, 0.618096, 1.799850, 1.647136, 0.890175},{0.826713, 0.058561, -0.268752, -0.213492, 0.815200, 0.965833, -0.963817, -0.161241, -1.572921},{-1.143502, 0.383932, -0.287385, -0.422993, 0.921961, 0.426995, -0.780011, -1.976317, 0.157150},{-1.027427, -0.050678, -0.561238, 0.619937, 0.911490, 0.145392, -1.460400, 0.509625, 1.230517},{-0.682262, -0.774861, 0.468064, 0.446646, 0.185754, 0.679024, 1.409915, 0.351771, 1.317070},{-0.086449, 0.779442, -1.585195, 2.376408, -1.946548, 0.582593, -1.089139, -0.419942, -0.515036},{-0.315228, -1.489092, -2.180577, -1.154734, -1.538410, -0.541833, 0.845012, -0.428669, -1.324264},{0.758754, 0.335349, -0.599932, -1.818995, 0.152641, 1.562859, 2.486625, 1.339876, -0.673230},{0.976087, 1.708282, -0.822928, -0.196690, -0.677269, 1.521029, -1.128685, -0.311804, 0.006130},{-0.292115, -2.626800, -1.750850, 0.373106, 0.188221, 0.107513, 0.042264, -0.504896, 0.721968},{-0.065035, -2.552616, -0.954167, -0.644790, -1.292020, -0.312820, 1.175033, 0.297949, -0.452384},{-0.719335, 0.339031, -1.319538, -1.828776, -2.150709, -0.870365, 0.440348, -0.313385, 0.765802},{1.023346, 1.581382, 0.627615, 0.150860, -0.604001, -1.429063, -0.723235, -0.210706, 0.149015},{0.904847, 0.261520, -0.406031, -0.470236, 0.993845, -1.213299, -0.259783, 1.618911, 0.189980},{0.500855, -0.324494, 0.160045, -0.830594, -0.235380, -0.772885, -0.402232, 1.548843, 0.408265},{-1.561586, 0.618524, 1.067445, 0.099073, 0.415364, -1.230636, -0.518073, 1.011521, -0.029012},{-0.767390, 0.127017, -0.648495, -0.727976, -2.070228, 1.001307, -0.237785, 0.884037, -1.649163},{-1.070363, -0.420539, -1.618324, -1.046035, 0.024705, 1.204757, 1.308117, -0.170442, 0.263830},{0.828953, 1.125157, 0.587995, 0.403536, 0.471878, 0.706451, 0.179401, -1.009975, -1.458319},{-0.471583, -0.730317, 1.847154, -1.047404, -1.315721, -0.961410, -0.454534, 0.172706, -1.544088},{0.007837, -1.223583, -0.535944, -1.657756, 0.029071, -2.598134, 0.995474, 0.770268, 1.410275},{-1.843447, -0.011425, 0.492355, 1.944950, -0.885311, -0.467375, -0.756213, 0.807076, -0.074075},{-0.903707, -0.644260, 0.336566, -0.233991, -0.483671, 0.462045, -0.648820, -0.422842, 0.862848},{0.906218, -1.336105, 0.406618, -0.485597, -0.772557, -2.125530, 1.178616, -1.073556, 0.396339},{1.027006, 2.762387, -1.539633, -0.424311, 0.175268, -0.273640, 0.030862, -0.510375, 2.403333},{0.661221, 0.992261, 1.078578, -0.128408, 0.121056, 0.591802, 2.793000, 0.237295, 0.164244},{0.129300, 1.390418, 1.911016, 0.610096, 0.038634, -1.470605, -0.518304, 0.057231, -0.690579},{1.380541, -0.055757, -1.085785, 1.003807, 0.526136, -0.803084, -1.711371, -1.128451, -0.270989},{-0.385553, -1.326250, 0.760806, -2.218830, 1.318255, -1.922136, -0.528939, 1.111270, -0.720749},{-0.274093, -0.176426, -1.347493, 2.202511, -0.089794, -1.269405, 0.302257, 0.009031, -1.165521},{-0.891455, 0.749942, -1.525055, -0.864829, 1.121312, -0.579250, 0.128619, -0.584062, -0.648784},{1.218329, -0.925279, -1.201054, 1.208901, -0.013811, -1.608608, -0.713305, 0.607836, 0.607453},{0.752538, -0.311810, -1.307634, -1.302995, -0.501657, 0.722044, 0.093775, -2.264769, -0.277279},{-0.121984, 0.277036, 0.583279, -1.455825, -0.676008, 1.159768, 0.790686, 1.121464, 1.304180},{1.560832, 0.594901, -0.901213, 1.380883, 0.412928, -0.236061, 0.981567, -0.212253, -0.318330},{0.338560, -0.409395, 0.665387, 0.050584, 1.143886, -0.354566, 0.316148, 1.476300, 0.167434},{0.502654, -0.334407, 2.352041, -2.656384, -0.693352, -0.247718, -0.479772, 0.487227, -0.370692},{-1.240332, -0.714705, -0.697339, 1.747279, -1.203179, -0.906636, -0.946892, 1.431760, -0.167418},{0.459861, -1.180387, -1.101359, -0.481204, -1.013612, 1.077987, -0.610324, 0.578690, -0.805484},{-0.210133, -1.818668, -1.777836, 1.457153, -2.305819, 1.628590, 0.702971, -1.493241, 0.996417},{2.570822, -0.668625, 2.087160, 0.530656, -0.704075, -0.335140, 0.233968, 1.002323, -1.927400},{-1.899652, -0.582715, -0.020701, -0.014330, 0.919189, -1.177168, 0.541367, -0.018092, -0.099775},{0.435094, 1.151202, 2.566492, 1.101218, 1.658359, 1.047891, -0.577349, -0.890919, -0.493889},{0.604129, 0.662363, -1.881022, 1.187858, -1.053222, -0.355687, 0.581862, -0.494549, 0.917978},{0.001141, 0.918601, 1.719732, 0.114970, -0.867338, -1.002546, -0.597389, 0.495001, -0.156583},{0.753722, -0.828047, -1.746790, -0.598639, 0.138400, -1.708116, -1.595648, -1.460031, 1.379912},{0.656630, -0.415770, -0.516357, -0.996574, -0.637924, 0.950147, -0.327670, -0.437918, 1.215906},{0.759621, 0.774193, 2.439476, 1.193472, 0.784092, 0.065261, 1.279197, 0.131617, 0.557273},{-0.905665, -0.379568, 0.810595, 0.728785, 0.847455, 0.523131, -0.810632, -0.615104, 0.546854},{1.272882, 0.459567, 1.302302, -1.105682, 0.261897, -0.427580, 0.908860, 0.557957, 0.070559},{-1.668907, -0.672642, -0.841836, 0.787406, -0.597849, 1.385688, -0.252091, -0.892702, -1.204106},{0.649655, 0.113022, -0.994798, -0.294722, -0.071280, 0.785612, -0.028844, -0.580426, -1.071809},{0.331471, 0.105164, -0.377613, -0.088190, -0.339707, -0.934073, -0.607162, 1.064572, 0.597035},{0.191453, 1.787304, -1.898597, -0.208089, 0.260595, 0.083261, 0.320567, 2.677137, -0.721762},{-2.092842, 1.273299, 0.970852, -0.762078, 1.894989, 1.594824, 0.744128, -0.809503, 1.849111},{-0.241764, 1.808746, -0.344935, 0.191522, 0.626609, -0.935591, 0.840090, -0.955749, -0.052880},{1.460646, 0.787274, -0.351933, 0.286468, -0.094629, 1.145137, -0.250449, 0.685337, -1.366863},{0.232254, -0.351580, 1.000837, 1.769108, -0.746268, 0.356928, -0.341502, -0.285774, -0.223756},{-2.162055, -1.439731, 1.238371, -0.382217, -1.666338, 0.318516, -0.466737, -0.155885, -0.234993},{-0.717208, 0.835660, 1.123550, 0.816283, -1.488314, -0.751759, -0.761494, -1.049052, 0.074914},{1.747653, -1.250384, 1.311665, 1.398995, -1.765582, 1.067084, -1.446399, 0.101403, -0.008296},{0.090259, -0.142477, -0.897023, 1.609988, 0.099890, 0.826700, -1.764884, 0.173074, 0.936977},{-0.067083, -1.624756, -0.833239, 1.417082, -0.694014, -1.897811, -2.721528, 2.887846, 0.518572},{1.579663, 0.553978, 0.932151, -1.029195, 0.234651, 0.724418, -1.477651, 0.370826, 1.073305},{-0.531973, 0.388771, 0.396720, -0.467826, 0.902367, 2.176412, 1.159383, -0.201027, 0.523476},{-0.898569, 0.763747, 0.025556, 1.180621, -0.406696, -1.760280, -0.579850, 0.203022, -0.033078},{0.795785, 0.097131, -0.488583, -1.212533, 0.883470, 1.429333, -0.489818, 0.597151, -0.717647},{0.316961, -0.634528, 0.860118, -0.487080, -0.590023, -0.177435, 0.187103, -1.011991, -0.700462},{-1.209383, -0.928834, -0.150848, 0.482180, -0.339491, -1.707540, 0.216814, -0.878050, 0.335391},{1.383885, -0.262357, -1.771709, 0.088812, -1.364309, 1.430301, 2.117473, 0.653474, -0.930925},{1.719082, 1.262164, 0.691750, -0.032658, 0.929272, -2.194525, 0.451904, 0.331504, -1.413189},{-1.814828, -2.177812, -0.324956, -0.325054, 0.730601, 1.094041, 0.377013, -1.806960, 0.630374},{-1.291429, -1.498491, 0.588236, 0.636024, -0.874654, 0.331270, -1.473291, -1.221219, 0.850074},{-0.090138, 0.148449, -0.607411, -2.237513, -1.809908, -0.688975, -0.774176, -0.774257, -1.640858},{-0.343151, -0.542730, -1.406518, 0.177718, 1.516795, 0.925951, 1.407597, 0.540826, -2.493179},{-1.140490, 0.655923, 0.565078, -0.443783, 0.122047, -1.341119, 0.126490, -1.395004, 0.048467},{-1.451949, -0.800230, 0.260043, -0.688484, 0.271326, -0.478450, -1.285290, 0.477576, 0.680844},{-1.237614, -1.512410, -0.696383, 0.546756, -2.379370, 0.958085, 0.529419, 1.105494, 0.004926},{2.143963, -1.220916, 1.000593, 1.193341, -0.526592, -0.716975, 0.618067, -0.048600, -1.380745},{-1.718633, -0.563174, 0.634351, 0.034103, 1.717024, 0.613549, 1.216731, 0.305033, 0.878856},{0.534804, 0.995971, 1.192746, 1.091701, -0.940609, 1.158436, 0.482599, -0.163741, -0.571323},{0.667859, -0.603996, -0.734137, 0.974390, -1.169087, 0.044179, -0.644559, -0.358565, 0.300640},{1.133062, -0.901399, -0.322927, -1.176452, 0.015821, -0.456047, 2.058729, 1.061496, -1.426177},{-1.383451, -1.029025, -1.014330, -0.732077, -0.437409, -0.907818, -0.266137, -0.290481, 0.428632},{-0.329869, -0.047405, 0.758078, 1.078117, -0.307260, 0.742508, -1.613093, -0.007871, 0.348103},{-0.958841, -1.156181, 1.780334, -0.957749, 0.366413, 0.975691, -0.916929, -1.633760, 1.119354},{-0.849490, -0.231756, 0.139677, -1.010072, -1.457596, -0.475966, 0.010062, 0.232003, -0.291452},{-0.707387, 1.445462, 1.851862, 0.616880, -0.822230, 0.384760, 0.299401, -0.415102, -1.418779},{0.171801, -0.432682, 0.029315, 0.455866, -0.338825, 1.506264, -0.242304, 0.324860, -1.401921},{-1.881482, 0.315318, -1.540743, 0.828853, -0.988890, -0.210561, -1.234798, 0.425322, -1.665212},{2.378884, 2.298898, -0.599312, 0.939965, -1.556245, -0.790512, 0.059968, -0.093631, 0.085214},{0.742179, 0.719279, -0.229228, -0.597235, -0.753703, -1.595430, -1.111382, 0.715961, -0.710087},{-0.433523, 0.184643, -0.508228, 0.316717, -2.224213, -0.865664, -0.001160, 0.503411, 1.691661},{-1.232922, 0.820734, 1.778979, -2.259553, 0.149575, -1.124881, 0.021485, -0.572483, 1.503925},{0.847182, -0.872600, 0.059714, 0.299901, 0.785677, 1.242395, 1.315395, -0.163333, -0.166650},{0.026552, -0.707045, -0.123076, -0.770771, 1.106415, 0.264504, -0.681182, -0.095119, 0.828609},{1.129542, 0.550029, 0.386297, -1.622364, -0.661740, 0.368367, -0.482981, -0.467323, 0.624160},{0.325775, 0.344083, -0.533314, -1.071269, -0.881782, -0.897701, 0.407363, 0.824945, 0.113979},{0.360567, 1.529813, -0.453417, 0.493058, 2.504122, 0.601843, -0.181325, 0.993377, 0.714906},{0.808042, 0.090428, -0.110544, 2.462415, 0.916888, 0.177931, -0.822078, -1.173805, 0.558973},{-0.509692, -0.970146, -0.180048, 0.895755, -1.608800, -0.243145, 0.897156, -0.658743, 0.286007},{-1.825975, -0.013959, 0.259344, -1.786989, -1.076670, 0.348721, 1.130038, -0.102777, -1.690566},{-1.139534, -1.387330, 2.026788, 0.241091, -0.186332, -0.712167, 0.036669, 1.585575, 1.655482},{-0.915549, -0.152867, 1.195427, -0.424583, 0.688530, -0.170736, -0.270789, -0.751085, 1.525811},{-0.441545, 0.350384, -1.020211, -1.095247, -1.462771, 0.298564, 1.356507, -0.169543, 0.538301},{-0.074660, -0.140937, -0.464513, 0.604352, -0.138393, 0.351366, -1.038777, 0.193824, -0.881555},{0.821346, -0.786545, 0.052533, -1.300072, 0.566452, -0.252625, -0.009393, -1.005268, 0.124719},{0.163282, 0.053127, -1.277128, -1.593422, 1.045683, -0.664946, 0.756694, -0.699136, 2.044156},{-1.014791, -0.194290, 0.543162, 0.411323, -0.757416, 0.924904, -0.892738, -0.820226, 2.569437},{0.717230, -1.159883, 1.879357, 0.393792, -0.890131, -0.615358, -0.054791, -0.181631, 1.576912},{0.935613, -0.684593, -2.388382, 2.018116, 0.158115, 0.196936, -0.830003, -0.166963, -0.486279},{-0.520731, -0.574023, 0.420039, 0.143831, -0.494129, -0.699634, -1.176115, -1.191588, 0.957221},{2.139817, -0.742979, 0.542024, -0.385485, -0.914958, -0.139478, 0.607933, 0.595888, 0.225937},{-2.172119, 0.256438, 1.065613, 1.026660, 0.527935, 0.806405, -0.099944, -0.129632, 1.291179},{-0.346078, 0.244245, 1.688889, 1.125684, 0.493673, 0.108181, -0.639628, -0.070706, -0.748153},{1.657685, -1.712825, 2.049533, 0.314992, -1.033699, -0.062089, 0.179726, -0.984777, 2.270748},{-2.113069, 0.105757, -0.382255, -0.081742, -0.935977, 0.954245, -0.275880, 0.771785, 1.196743},{-2.044088, -0.226308, 0.902410, 1.061087, 1.152884, -0.279781, -0.922199, -0.433100, 0.566463},{0.678889, 1.124164, -1.472256, -0.123563, -2.303330, 0.470836, 0.394377, 0.193411, 0.014080},{1.560901, 1.283980, -1.034762, 0.760783, -0.351367, 1.192001, -0.231373, 0.342821, 0.258118},{-0.686428, -1.345469, -0.843966, 1.208472, 0.354086, -1.833516, 1.086123, -1.115969, 0.812495},{-1.456094, 1.206425, -0.537572, 0.536469, 0.451197, -1.506209, -0.479200, -0.589983, 0.594171},{0.094555, 0.555180, 0.156027, 1.408621, 1.509900, -1.464725, 1.952441, 0.261205, 0.597055},{0.100356, 0.344096, -0.457441, -0.345244, -0.447336, 0.754136, -1.202729, 0.703011, 1.068480},{-0.764525, 1.147668, -0.063124, 0.406091, 0.416977, -0.757409, -0.011725, -0.446583, -0.623777},{1.674832, -1.723254, 0.912782, 0.554940, -1.656564, 0.217916, 0.243702, 1.450635, 2.609202},{0.855002, -0.744360, -2.899108, 0.681090, 0.802166, 0.175188, -0.023239, -1.846247, 0.134478},{0.250771, 0.445712, 0.791234, 0.215115, 0.967718, -0.808375, -0.565308, 1.154543, -0.617143},{1.210947, -0.240044, 2.684637, -0.241857, 0.614943, 1.689987, 2.292470, -0.007307, -0.142415},{0.097533, -0.729083, -0.247488, -0.031330, 0.211372, 1.435275, -0.333433, -0.281812, -0.677267},{-1.112953, -0.708490, -0.231775, 1.541733, 0.167632, -0.456612, 0.401818, -0.455763, -0.541460},{1.135767, -1.358367, -0.795678, 0.844750, 1.132216, 0.366825, -0.093686, -1.174861, 0.793653},{0.468991, 0.020399, -0.108735, -0.318212, 0.316006, -1.798537, -0.928436, 0.144099, 0.808294},{-0.739950, -0.305304, -0.856473, -2.253580, 0.372686, 0.521028, 1.227812, -0.783795, 1.371267},{-1.326254, 0.388628, -2.732513, 1.156617, -2.239182, -0.044482, -1.857537, 0.914350, 0.609286},{-0.130969, -1.239293, -0.423764, -1.450259, 1.181501, -1.317501, 1.796838, 1.952625, -0.319163},{-1.500060, -1.526813, -0.899374, 1.057271, 0.057609, -0.040716, 0.384303, -0.685227, -2.222443},{-0.873752, -0.162455, 0.148626, 0.675142, -1.708400, -0.965404, -0.058934, -0.890505, 0.351572},{-2.147138, -0.078824, 0.586685, 0.975159, -1.718587, -0.145923, 0.961864, 0.297069, 0.609410},{1.671133, 1.325876, 0.584182, 0.513856, 0.430847, 0.681463, -0.405735, 0.339291, 0.375344},{-0.165478, 0.425334, -1.732582, 0.829848, -0.822541, 0.563498, 0.568729, 1.302811, -0.761149},{-0.647473, 2.921022, 0.416809, -0.115455, 0.851106, -0.358497, 0.117966, -0.232924, -1.387577},{0.288679, 0.703620, -0.326650, 0.974074, 0.357973, -0.310947, -0.875385, 0.403645, -1.140695},{0.629139, 2.121117, 0.617380, -1.360705, 1.288669, -0.211436, 0.786449, -0.965733, 0.284858},{1.493918, -0.038650, 0.427593, 1.488342, 0.993621, 0.298380, -0.410305, 0.179614, -0.509811},{-0.543870, -0.473363, 0.420548, -0.117571, 2.079334, -1.053830, -0.406406, 0.692454, -0.410118},{2.179127, 1.060602, -0.285258, 1.349167, -0.500948, -0.160889, -0.266016, -0.486905, -0.625234},{0.381631, 0.180632, 0.059323, 0.165671, 0.455056, 0.719959, 0.261872, -0.933727, -0.796325},{1.951032, 0.631695, -0.277526, -0.304704, 1.167144, -0.066708, -0.690434, 1.488883, -0.554331},{1.436559, -0.450005, -0.173679, 0.708677, 2.753107, 1.739401, 0.036898, -0.163087, 0.090646},{0.256882, 1.675447, 0.865303, 1.310718, -0.213565, -2.726151, -0.358808, 1.450904, 0.368007},{0.334832, -2.292925, -0.307599, -0.957592, 0.326948, -0.234405, -1.022746, 0.441742, 1.249277},{-0.261089, 0.708313, -0.964359, -0.112762, 0.789312, 0.885136, 0.486931, -0.052376, -0.969982},{-0.756845, -1.004081, 1.230680, -0.263169, -1.029669, 0.463763, 0.447129, -0.130060, 0.585091},{-0.481858, -0.850600, 1.744142, 2.014305, 0.516792, 0.607807, 2.245545, -0.741396, 1.249438},{-0.493419, -0.172745, -0.641606, 0.160316, -1.474491, -0.609389, 0.478404, 1.374379, -2.422431},{-0.243673, 0.787621, -1.466437, 0.386398, -0.498727, -0.614246, -0.400784, -0.130755, 1.562620},{-1.006470, 1.302645, 1.388082, -1.411051, 0.064502, -1.704898, -0.830365, -0.264196, 0.077375},{0.087688, -1.040517, 0.067585, 0.096650, 0.304848, -0.716995, -0.780846, 2.932360, 2.643728},{0.852771, -1.155809, 0.338351, 2.022967, 0.219156, 0.688568, -0.196571, 2.698208, 0.781633},{-1.649167, 0.844921, 0.082037, -0.204390, 0.847293, 0.395565, 0.836329, -0.415061, 0.472188},{0.154247, -0.768417, -0.669748, 1.976566, 0.709884, 1.123922, 1.493150, -0.504993, 1.403604},{-0.423582, -0.791546, -0.233066, -1.910996, 0.970212, -1.353871, 0.246375, -0.192339, -2.350561},{-0.605651, -2.170649, -0.623328, -0.021912, -1.027756, 1.832234, -0.343734, -0.788017, 1.182272},{0.728321, -0.357002, 0.158893, -0.081355, -0.484493, -0.101221, 0.553406, 0.225528, -0.990783},{-1.065977, 1.285949, -0.784269, -0.893008, -0.472719, -1.428321, 0.675655, 0.160303, -3.182025},{0.890064, -0.059774, 0.028426, 0.046246, 1.070842, 0.092715, 0.705961, -0.287098, -1.088273},{0.912821, -1.413950, 0.970414, 0.778447, -0.241000, 1.026122, -2.202250, -1.512814, 0.145559},{0.906383, -0.123780, 0.726109, -0.851334, 0.629408, 0.273971, 0.269133, 0.451384, -1.526722},{-2.344041, 1.451929, -0.432018, 0.404423, 1.655998, 0.821166, -0.250401, -0.774974, 0.019815},{0.546152, 0.507029, -1.475158, -1.575472, 0.207194, -0.444953, -1.972643, -0.891051, 0.923720},{-0.369758, -0.228187, 0.449780, 1.137035, -0.805128, -0.212737, -0.667626, 0.256139, 1.430114},{2.332092, 1.309579, -0.398358, -0.894283, -0.550258, -0.745937, 0.436137, 0.124545, -0.370812},{1.645319, -0.139680, 1.579217, -0.825241, 0.908900, -1.159758, -0.053652, 0.127269, 1.240070},{0.535474, -2.389506, -1.317159, -1.349553, -0.209333, 1.433751, -1.577776, -1.720221, 0.581762},{1.604014, 0.940515, 0.911922, 0.724043, 0.188686, 0.512927, -1.112169, 0.817983, 1.204090},{2.472644, -0.467280, 0.625179, 0.740759, 0.900332, 0.845432, 0.206257, -2.610252, -0.663911},{0.481658, 0.641078, 0.999540, -1.411453, 0.163978, -0.103730, -0.271904, -0.625377, 0.179189},{-0.261204, 0.005575, 1.262754, 0.820038, -0.001755, 2.105409, 1.410031, -1.688245, -1.055205},{1.164951, 0.151025, -1.031849, -0.143445, -0.001842, -0.689074, -0.372582, -1.628267, -0.330547},{0.161363, 1.237843, 1.104018, -1.310340, 0.152350, 0.792717, -2.783708, 1.719831, 0.738749},{0.273834, -0.543630, 2.128364, -0.355235, 1.016106, -0.174727, 1.613740, -0.802438, 0.839302},{-0.046704, 0.174870, -0.520259, 0.336678, 1.097343, -1.151536, -1.438335, 0.664789, -1.609602},{0.680684, -0.678497, -0.963421, 0.652090, -0.476177, -1.668116, -2.501169, 0.583545, 0.344400},{-0.289512, -1.723068, -0.187903, 0.742669, 0.580252, -2.334970, 0.334777, -1.132892, -0.069697},{-1.133073, 1.685571, -0.076024, 0.878322, -0.568733, -1.285502, 1.240616, 0.599829, 1.191557},{-1.122688, -0.972302, 2.130978, 0.085124, 0.212300, 0.081064, 0.111541, -1.996064, -1.427720},{-1.709760, 0.803119, 0.864328, 0.823553, -0.328807, 1.043308, -1.057948, -1.613284, -0.686184},{0.277821, -0.870085, 0.509001, -1.950303, -0.089305, -0.668356, 1.043629, 0.580406, -1.478113},{0.428170, 0.943670, 0.748372, -2.469297, 0.534647, 0.817916, 0.587538, -1.424779, 1.050616},{0.224194, -0.753981, -1.284466, 1.780891, -1.049330, -0.541674, -0.545154, 0.446926, -1.659550},{-0.624395, 0.782341, 0.456351, -0.646599, -0.483913, -1.283270, -1.435320, -0.720129, 0.909615},{0.226307, -0.258076, -2.590908, -0.381934, -0.451067, -0.150124, 0.064997, 0.846883, 0.545154},{0.880845, -0.083218, 1.073154, -0.933825, -1.102102, 0.492445, 0.705910, -0.771430, -0.457724},{-0.315217, -0.458545, 1.148124, 0.886681, -0.926822, 0.422975, -1.420842, -0.882311, 1.376060},{1.915000, -0.533624, 2.040362, -0.525994, 0.987406, 0.024172, 0.994098, -0.633168, -0.958460},{0.992125, -1.846597, 0.771830, 0.711112, 1.496965, -0.476544, 0.086669, -0.334818, -0.355588},{-0.692723, 0.404398, 0.770933, 0.073652, -1.128472, -0.880391, -1.207973, 2.099545, 0.125385},{1.591204, -0.248147, 0.801494, 0.050190, -0.503829, 0.071031, -1.173834, -1.063931, 2.394896},{-0.102666, 0.988666, -0.772905, 0.152702, -0.122106, -0.383699, 0.378886, 0.746572, -0.571978},{0.157778, 0.031953, -1.763510, -1.127702, -1.078008, -0.016341, 0.319975, 1.648828, -0.065533},{-0.380487, 1.131667, 0.440926, -0.057734, -0.788712, 0.032710, -0.749254, -0.131788, 0.724976},{1.529317, -0.804192, 0.661040, -0.714972, -1.300963, -0.193443, -0.673222, 1.104871, -0.172223},{-1.012731, -0.673734, -0.173760, 1.724760, -1.609016, 1.238555, -0.561054, -0.465190, 1.988075},{-1.411114, -0.027036, -0.564576, -1.508905, 0.003602, 0.950821, 0.606812, 0.980145, 0.724423},{0.404123, -0.490763, -1.011808, 0.581929, -1.312994, -1.433561, 1.688121, -0.238325, 0.679275},{-0.814359, -0.250764, -0.002445, -1.244180, 1.270663, 1.299512, -1.104810, -0.443006, 0.063567},{-1.166246, -0.112020, 0.180370, -1.004549, 1.571625, -0.157665, 0.112616, 0.003816, -2.150582},{0.019535, 0.499166, 2.668430, -0.237435, -0.071876, -0.185304, -1.086027, -0.685786, 1.050015},{-1.427750, 1.563139, 0.001315, 1.780102, 1.239417, -0.105654, 0.054595, 0.013422, 0.748075},{-0.766477, 0.476577, 0.068355, 1.032671, 1.727081, -1.254146, 0.427983, -0.201302, -0.277644},{-2.158727, -0.420220, 1.790401, -0.249118, -0.205224, 0.549135, 0.484121, 0.535389, -0.135854},{0.960874, -1.503123, 0.442664, -0.920064, 0.538826, 2.337604, -0.115986, -0.957897, 1.690929},{-0.405949, -1.287608, 2.185234, 1.017640, -0.184550, -1.112077, -0.331016, -0.517281, -0.866010},{0.494588, 0.583649, -0.569204, -1.742316, 0.147970, -0.603119, -0.828978, -1.603279, -0.723043},{-1.140183, -2.484600, -0.430098, -0.278979, 1.129933, 0.272447, -0.765948, -0.886393, -1.283839},{1.138518, 1.162976, 1.073108, 0.522246, 0.176825, -0.354673, 0.957904, -0.276854, 0.532276},{0.549054, -0.690534, 1.829721, -0.304887, 0.295994, -0.174577, -0.716415, -1.154851, -0.692691},{-1.334264, 0.197060, 0.211704, 0.368724, 0.421785, 0.518637, 0.352934, 2.083112, -0.101213},{-0.357028, -0.448958, 0.522075, 0.655948, 0.321674, -0.358966, 0.970546, 0.180932, 1.036969},{-0.339362, 0.093942, -0.880899, -0.708379, -0.549708, -1.400209, 2.033880, 0.279233, -0.078982},{0.381218, -1.344601, -1.409413, -0.425432, 0.790093, -0.121330, -1.532554, -0.911767, -2.572154},{0.102803, 1.228253, 0.734228, 1.185484, -1.593761, -0.683808, 0.084747, -1.409025, -0.943466},{-0.590813, 0.302522, -2.843583, -0.920059, -0.206348, 0.128702, -0.331784, 0.624199, 0.775674},{1.099306, 0.083773, 1.395257, -0.788636, 0.898969, -0.623685, 0.544076, 2.144590, 0.834772},{-1.211759, 0.526877, 0.007882, 0.929474, 0.849579, -1.469009, -0.611912, -0.757895, 1.854769},{1.931800, 0.926773, -1.487000, -0.174290, -0.381579, 1.565495, -1.307847, 0.029139, -0.065257},{-1.299157, 1.315313, 0.017643, -2.301022, -0.334217, -1.712717, 1.805673, -0.579155, -2.211166},{0.131418, 0.447339, -0.925864, 1.523136, -0.814899, -0.187902, -0.090285, -0.848058, 0.498417},{-0.725718, -1.234444, 0.697008, -1.047578, 0.162117, -0.915278, -0.943967, -2.746883, 0.282207},{0.113452, -0.383786, 0.564336, 2.084764, 1.890892, 0.251691, -0.693156, 0.288675, -1.155233},{-0.293297, 1.168065, 0.926770, 0.843692, 0.277513, 1.724763, 2.106818, 0.451360, 0.470519},{-0.351640, 0.622193, 0.862538, 0.149152, 0.719228, -0.324453, 0.048496, 0.975085, -0.376830},{-1.890227, 1.017341, -1.688682, -0.543287, -0.082329, 0.313803, 0.330389, 0.638498, -1.758943},{-0.918046, 1.270134, 0.901526, 0.917763, -0.545900, 1.134830, -0.689901, -0.162790, -0.169689},{0.505136, 1.063377, 2.148046, -1.445307, 0.609454, 0.309182, 0.694618, -1.951104, 0.601472},{0.166522, 0.540113, -0.455073, 0.652615, 1.646541, -0.892803, 0.552604, -0.671546, -0.523033},{-0.603437, 1.891042, -0.159899, 0.391237, 0.282200, -0.128510, -0.344479, 0.225119, -1.155210},{-1.589933, -1.267360, 0.373499, -1.747501, 0.098653, 1.180711, 0.321209, -0.134968, 1.304592},{0.443431, -0.185200, 0.597389, -1.248001, 0.194195, -1.745815, -1.225533, -1.410178, 1.527589},{-1.181933, 0.234809, -0.858550, 1.645988, -0.093341, -0.846607, -1.039165, 2.192743, -0.015251},{-0.483534, 0.340945, 0.036136, 0.555930, 1.654463, -1.748424, 0.322670, 0.676822, 1.928782},{0.523256, 1.071785, 0.219023, -0.180401, -0.523128, -0.781315, -1.589705, -0.117311, 0.603068},{0.354516, 0.768141, -0.800836, 0.425642, 0.799639, 0.473933, -0.207454, 1.416789, 0.307915},{0.303016, 1.908046, -1.087076, -1.995372, 0.528250, 2.360635, 0.312607, -0.164069, 0.046047},{-0.054888, 1.608213, 0.050402, 0.654523, -0.472487, -0.909723, 0.645948, -0.549244, 0.796794},{0.232888, 0.000209, 1.076199, -0.298748, -0.838092, 0.676657, -2.075142, 1.594389, -1.539192},{0.340914, -0.768869, -0.479519, -0.096726, 1.670282, -0.771616, 0.755669, 1.510876, -0.499347},{-1.177998, 0.565753, 0.017838, 0.775699, -0.229695, 0.351947, 0.053996, 0.563231, -0.260755},{1.147720, 0.646087, -0.637005, -0.665761, -0.372811, -1.086229, -1.350394, 0.393230, -2.371913},{-0.519417, -1.624898, -0.821755, 0.948815, 0.364390, -0.422930, -0.267512, -0.475274, -1.730594},{-0.292916, 1.935603, 1.216526, -1.928152, 0.272980, -0.365445, -0.151465, 1.020924, 0.577926},{0.048751, -0.474486, 0.587342, 0.713101, -1.374171, -0.320951, 0.655313, 0.309779, 0.083164},{0.856264, 0.852693, 1.049282, -0.706965, 0.485645, -0.110310, 0.094682, -1.562288, 0.217535},{0.222046, 0.263668, 2.413100, 0.254001, -0.165393, -0.086050, -1.108609, 1.480240, 0.503577},{0.865416, 0.212891, 1.452443, 0.074657, -0.751718, 1.112010, -1.051457, 1.334149, 0.651102},{-0.548821, 0.551880, -0.301032, -1.310080, -0.159136, 0.975139, 0.664679, 1.465274, 1.977728},{-0.820615, 0.381302, 1.364803, 0.958155, 2.048404, 0.574852, 0.584528, -0.262735, 0.388992},{2.283521, -0.667266, 0.247859, 1.424472, -0.722075, 0.272546, 1.098371, -2.518621, 1.655385},{-0.070729, 0.356620, -1.824293, -0.513846, 1.615025, -1.053030, -1.020414, 0.152106, -0.552579},{2.017101, -0.791880, 0.072687, -0.959731, -0.511844, 0.744969, -0.470121, -0.708944, -1.313676},{-0.519403, 0.599818, 0.513410, 1.126904, -0.027674, 0.321056, 1.644480, -1.444686, -1.321624},{-1.920049, -0.954509, -0.052775, -0.120009, -0.096773, -0.502140, -0.197134, -1.680949, 1.405018},{-0.323774, -1.420765, 0.157836, -0.241667, -0.286535, 0.884134, -2.309351, 0.906871, -0.053070},{-0.416761, -0.435011, -0.454957, 0.578802, 0.646177, 1.177583, 1.073715, 0.181006, -0.485579},{-0.726086, -2.505583, 0.417187, -2.070315, -0.009871, -0.007648, 0.313475, 0.662962, -0.628636},{-0.121731, 1.162080, 0.394540, 1.026791, -1.022609, 0.007279, -0.490910, 1.808535, 1.205904},{1.849332, 0.216426, 0.970416, 0.376858, -0.496381, -0.204104, -0.254152, 1.320479, 0.772628},{0.294227, 1.083117, 0.246107, -0.530704, 1.741116, -0.356288, 1.032484, -0.300746, -1.847369},{1.067759, 1.217303, 0.105722, 1.210538, -0.588588, -0.922877, -0.460128, 0.520144, 1.561766},{0.032750, 0.719843, -0.763923, 1.487963, 0.031637, -1.249411, 0.992137, 0.656185, 0.616852},{-0.802492, -1.270169, -0.346475, 0.841822, 0.104067, 1.418745, -0.043936, 1.130268, 0.271639},{-0.539545, 0.632899, 0.472966, -0.704334, -1.263410, 0.137363, -1.588585, 0.888152, -0.428547},{-0.761238, 0.801415, 0.166015, -1.082667, -1.367584, -0.962139, 0.074792, -2.118039, -1.354648},{1.508992, -0.345496, -0.562371, 0.563187, -0.675036, -0.948639, 1.109298, -0.037018, -1.119075},{0.701780, -1.590603, 0.881685, 1.026810, 0.376855, 0.988681, -0.992528, 1.685434, -0.035805},{1.076133, 0.028970, -0.151819, 2.162596, -1.518013, 0.050068, 0.751963, 2.490456, -0.137060},{-0.406787, 1.471030, 0.008748, -0.816999, 0.498837, 0.426422, -0.451339, -0.845975, -0.105973},{-0.688501, -0.276504, -0.343400, 3.213595, -0.079277, 1.243307, -0.091724, 3.056675, -0.985342},{0.202409, 0.245955, -0.840551, -0.648102, -0.298815, -0.591453, -1.078537, 0.538329, -1.644358},{-0.250798, 0.900956, -1.448119, 1.061844, 0.039027, 1.570624, 0.941326, -0.239849, 0.829622},{-2.485199, -0.462723, 0.335171, -0.763369, -0.623109, -1.219636, 1.730782, 0.056560, -0.519071},{0.221641, 0.561615, -0.585570, 1.124449, -0.783644, 0.239514, -2.019220, -0.578192, -0.808179},{0.228080, 1.652292, 1.039914, 2.094474, 0.317382, -0.895424, 0.334599, -1.719164, 0.089142},{0.032496, 0.215408, 0.839635, -1.393347, 0.755749, -0.779988, -2.031426, -0.076297, 0.097673},{0.396082, -1.738560, -1.012505, 0.463464, -1.143412, -0.126648, -0.802849, 1.060640, 0.396780},{1.281619, 0.338394, -2.577631, -0.224886, -0.564633, -0.055895, -2.058985, -0.729211, -0.317012},{1.144131, -0.194717, 0.493092, -0.174165, -0.999964, 0.946504, 0.653273, 0.028535, -0.769720},{-0.026649, 0.695499, -0.435273, -0.402916, 1.384493, -0.314354, -0.230861, -0.573295, 0.799158},{0.492521, 1.126689, 1.723579, -0.469382, 2.096864, 0.859302, 0.582590, -0.293704, 1.329406},{0.273338, 0.201696, -0.475499, -0.890938, 2.671036, 0.723677, 0.448360, -0.256012, -1.045996},{0.170032, -1.007274, 0.023360, 1.712669, -0.653784, -2.166224, 0.552389, 0.695462, -1.734660},{-0.589831, 0.092479, 1.850350, 1.126282, -1.775075, -1.852347, -0.461191, -0.170071, 0.270327},{0.215868, 0.301950, -1.016214, 0.006735, -0.214833, 0.426797, -1.236223, 0.942594, -0.337440},{-0.551472, 0.729511, 0.549126, -0.352234, 2.138294, -0.407072, 0.869827, 1.791595, 0.597832},{-0.467648, -0.648587, 0.449136, -0.205266, -2.203651, 0.132462, -0.360258, -0.027281, 0.635647},{-0.471334, -0.293497, 0.002108, -0.668464, -1.655072, 2.077931, 0.373430, -0.844653, 1.219268},{-0.488919, 0.818563, -1.802763, 0.206621, 2.266024, -0.291452, 1.027528, -0.613333, 0.401318},{0.018576, 0.957380, -0.412215, -0.040456, -0.157009, -0.878013, -0.625075, -0.117102, 0.395632},{-0.654850, -2.098733, 1.118304, 1.213172, 0.070332, -1.791103, -0.833903, 0.361563, 0.250563},{-1.859241, 0.696959, 0.558687, -1.254865, 0.562164, 1.384379, -0.644458, -1.148720, -0.719778},{-2.302635, 0.885766, -0.588618, -0.827388, -1.247786, 1.102690, -1.895098, 1.177062, 0.987849},{-0.553167, -0.239254, 0.494700, 0.243635, -0.343807, 1.696959, -0.131472, 0.123158, 0.348519},{2.344846, -0.800393, -0.549806, 0.713493, 1.070094, 0.204008, -0.536829, -0.117227, 1.247214},{-0.954844, 0.852674, 0.800281, 1.948589, 0.114714, 0.558857, -1.056679, -1.303875, 0.577318},{2.241117, -0.014710, -0.598925, 0.187471, -0.651608, 1.339594, 0.233612, -0.354227, -0.210835},{-0.157783, 0.069439, -0.360598, -0.417913, -0.055245, 1.101292, -0.746321, 0.254776, -0.425705},{1.490484, 0.840557, -0.330971, 1.460761, -1.005819, 0.721474, -0.793699, 0.618628, 2.452263},{-2.072776, 0.571470, 0.918838, -0.158222, -0.247155, -0.214502, -1.000145, 1.005302, -0.490440},{-1.494851, 0.575723, -0.264734, -1.300801, -2.229822, -1.187523, -2.992745, -0.024250, -0.804564},{1.451752, -0.025922, -0.362690, 0.206836, 0.263981, -1.451707, 1.235281, 0.542704, -0.366031},{-1.018347, -1.677444, -0.806574, 0.469601, 1.099368, 0.728078, -1.404809, -1.139942, -0.814516},{-0.985650, -0.921320, -0.064928, -0.513125, -0.837179, -1.251695, -0.608581, -2.050520, -0.088392},{1.125241, 0.831430, 0.650264, 0.758332, -1.615159, -2.606283, 0.983115, -0.030432, 0.453585},{0.256524, -0.640424, 0.395472, 1.245945, 0.870576, 0.602813, 0.077534, 1.005452, -0.401064},{-0.934884, -0.396291, -0.300215, 0.400955, -0.766654, -0.395338, 0.633906, -0.412878, 1.037202},{-0.937692, -0.783789, -1.392363, 1.515978, 0.596311, -0.920691, -0.388249, -0.237134, -0.588449},{1.063787, -2.034653, -0.188061, 0.442765, -1.998343, -0.465301, 0.227209, 0.100244, -0.593802},{-1.832969, 0.536420, 0.081939, 0.124642, 0.283586, -0.196647, -1.074988, -1.785207, -0.687467},{0.406187, 0.453127, -0.625813, 1.086205, -0.864522, -0.441794, 0.694708, 0.694385, -0.390504},{0.698970, 0.466512, -0.779348, -0.066395, -0.186994, 1.602810, 0.960385, -1.277221, 0.188310},{0.656045, -1.573054, -2.086292, -0.016223, 0.391741, -1.084102, -1.377499, 1.123845, 1.038944},{1.604743, 0.875912, 0.902477, -1.541675, -0.719216, 0.534118, -1.060643, -1.896134, -2.237344},{1.119514, 0.531782, 1.247905, -2.601475, -1.873803, 0.404182, -0.592798, -0.481176, -0.298899},{-0.451041, 0.476547, -0.660227, -0.575052, 0.621812, 0.936065, -0.425231, 1.418568, -0.386898},{-0.260520, 0.610527, -0.758203, 0.504544, -0.179332, -0.246865, -0.790518, -1.408995, 1.521652},{1.462415, -0.024492, 0.066101, 0.706683, -1.294984, -0.344050, 0.177561, -0.018982, -0.569730},{1.002904, -0.198219, -0.705580, -1.343080, 0.184976, 0.637722, 1.464452, 1.374907, -1.079497},{0.168739, -0.136180, -0.747583, -0.098147, -0.407093, -1.133891, -0.478555, -0.569481, -1.018399},{0.170940, 1.307432, -0.720113, -1.440107, 0.849954, -0.880765, -0.118583, 0.361966, -1.336378},{0.285400, 1.815951, 0.185887, -0.360447, 0.176951, 2.158922, 0.842811, 0.762905, -0.301247},{-0.199253, 2.856287, 0.361818, 1.165829, -0.612533, -0.257394, -0.540748, 1.164084, -2.030807},{-1.262576, 0.742243, 1.093510, -1.211190, -0.222440, -1.787073, -1.033157, -1.972998, -0.754266},{-0.727410, -0.584187, 0.943021, -2.096824, 0.956503, -1.278508, 0.277330, 0.425134, -0.612059},{0.225833, -1.105398, 0.333787, 0.979099, 1.156315, -1.766431, 0.868838, 0.831912, 0.434042},{-0.229189, 0.907060, 0.429220, 1.109258, -0.206113, -0.710071, 1.179466, 0.902437, 0.750485},{1.118366, 1.675802, 0.245036, -1.518351, 0.402674, -0.327375, 0.689555, 0.298005, -0.038118},{0.194577, -0.409619, -0.007964, 0.265722, 0.336611, 2.503244, -1.469619, 1.490451, 0.269666},{-0.589644, -0.159471, 0.257996, -1.770648, 0.615000, 1.224792, -0.149391, -0.575714, -0.681747},{-0.200735, -0.395860, 0.575949, 0.026315, 0.471237, -0.964862, 0.979596, -1.308540, -0.211502},{-0.622494, -0.350088, 1.137905, -0.142398, 0.661047, -0.628127, -0.069688, -0.553851, 1.082098},{0.431586, -0.344114, 0.285200, -1.370307, 1.527788, 0.814044, 0.458140, 0.703521, -0.331038},{1.176601, 1.116948, -0.799409, 0.817165, -1.247989, -0.333403, -1.690962, -0.586187, 0.023218},{1.794953, -1.395993, 0.426703, -1.539569, -0.321013, -0.960826, 0.343217, 2.462861, -0.679427},{-1.426066, 0.296409, -0.023035, -0.548965, -1.234763, -0.434895, -1.180638, 0.532914, -1.204563},{-0.134652, 0.550058, 0.323124, 0.372352, 0.656552, -1.797042, 1.908194, 0.221581, -1.787671},{-0.426914, 1.291546, -1.002460, 2.128526, 1.167550, -0.472128, -0.662765, 0.675278, 1.280959},{0.413138, -0.023758, -0.757975, -1.613140, -0.385159, -0.001284, 0.811936, -1.946555, -0.073300},{1.539402, -0.121769, -0.651639, -0.593054, 0.906997, -0.001767, 1.752222, -1.004185, -1.651153},{-1.057584, 0.624282, -0.715961, 0.623020, 0.170737, 1.136199, 1.303377, -0.463892, 0.917908},{-1.781705, -0.422805, 1.173560, 0.922935, 1.125593, -0.155572, -0.629327, 1.201948, -0.420930},{-0.000370, -0.323814, -0.842571, 0.351625, -0.707131, 0.597839, 2.196482, -0.257986, 0.514222},{0.283790, -1.910994, 0.687593, -0.850183, -0.293523, -0.930313, -1.363891, 0.883806, -0.494965},{0.653467, -0.755123, 0.676833, 0.032158, 0.333797, -1.464429, -0.640705, -1.947446, -0.101399},{1.043464, -0.827061, 1.006125, -0.481854, -1.317922, 0.195925, 1.494303, 1.040123, -0.017047},{0.978136, 0.874484, 0.163507, 0.029712, -0.983472, 0.875428, 1.719972, -1.409356, -1.366994},{-0.612220, -1.306332, -0.259124, 0.318385, 0.841456, -0.155147, -1.415251, -0.539011, 1.595962},{-0.139429, -2.672216, -1.101273, 0.032648, 1.483873, -0.282386, -0.192662, -0.397689, 1.142234},{0.486802, -0.580258, -1.141475, -2.123137, -0.906465, -0.097074, -1.005219, -1.406326, 0.314869},{-1.747793, -1.137263, 0.295247, -0.013779, -0.813411, -1.114908, 2.655887, 1.119163, 1.183572},{-0.462458, -0.466191, -2.314050, -0.095430, 0.864589, 0.146681, -0.509598, -0.597641, -0.201816},{0.214107, 1.141630, -0.234350, -0.889047, -1.825458, 0.033065, 0.443902, -0.156482, 0.681105},{-0.574102, 0.182903, -0.020612, 1.939261, 0.886631, 2.516945, -0.852832, 0.840087, 0.788499},{-0.307692, -0.248358, 0.122686, 1.163855, 0.653871, -0.631703, 1.039484, -0.477839, -0.202488},{-0.539224, -0.489255, -0.463360, 0.133208, -1.112966, -0.652627, -0.462565, -1.823466, -0.627952},{1.521061, 1.290810, 1.428325, 0.591633, 1.346289, -0.620602, -0.488084, 1.179545, -0.456315},{0.491166, -0.300395, 0.702330, -0.933362, 0.190346, -0.095287, 0.346982, -0.382703, 0.298054},{-0.354128, 0.150260, -2.631484, -0.067777, -1.966648, 1.275173, -0.797143, 0.057126, 0.244714},{-0.545102, 1.192816, 1.154172, 0.463025, 0.987126, 0.858144, 0.391756, 1.299378, 0.559613},{0.423752, 2.838643, -0.793213, -0.545885, 0.572863, -0.393462, -1.927134, -0.866687, 0.660566},{1.189001, -0.768392, 0.790416, 0.186727, 0.519284, 1.228827, 0.025497, -1.014848, -0.700046},{0.963582, 0.592252, -2.276947, 0.128078, 0.815961, 0.835689, 2.165018, -0.167703, -0.981878},{-0.056986, -1.116482, -0.053619, -0.265778, -0.364658, 0.003175, 0.621808, -1.725049, -1.615798},{0.859706, -0.945349, 1.704239, -0.423789, -0.956417, 0.740446, -1.089013, -0.162413, 1.155185},{-0.283935, 1.188923, 0.725408, -0.538928, -1.659603, -1.053312, 0.696148, -1.905199, -0.297295},{0.062198, 0.231717, -0.658046, -1.131177, -0.751320, 1.021908, 0.674005, -2.278644, -0.381020},{-1.021774, 1.379921, 1.234714, 1.476369, 0.516849, 2.568398, -0.324922, -1.069694, 1.198323},{1.626023, 0.184705, 1.463278, -0.090518, 0.917881, 0.402132, 1.207819, -1.094040, 0.562069},{-0.007749, 0.046196, 1.062238, -1.276762, -0.117339, 1.227300, 1.057454, -1.502440, -1.208211},{-1.735374, 0.106841, -0.747858, -0.181918, -0.216032, 0.643889, 0.110246, 1.052528, -1.127336},{0.697505, 0.249741, 0.573430, 0.081287, 0.269368, -1.275248, -0.167173, -0.320276, 1.195670},{-1.201845, -0.471495, 0.727153, -0.235363, 0.762830, 0.102781, 2.099246, -0.193745, 1.218915},{-0.811152, -1.448592, 1.469764, -2.619675, 0.049442, 0.396730, 0.758080, -0.492686, 0.998870},{-0.280393, -0.216438, 1.913271, -0.154331, 0.938409, -0.753416, 0.171427, -0.921360, -0.719764},{0.095954, 0.918176, 2.097970, -1.130836, 0.878953, 1.217419, -0.092507, -0.757212, 0.083361},{0.799326, 2.322527, 0.266280, -0.792287, -0.385673, 0.447113, -0.978847, -0.571501, -1.347889},{-1.587724, -1.486801, -1.001104, 0.967894, 0.843073, 0.676359, 0.106377, 2.189506, 0.023232},{-0.376590, 0.154608, -0.176763, 0.636603, 0.493110, -0.887508, -0.622051, 0.612378, -0.854787},{-1.608395, -1.427701, 0.958859, -0.517637, -0.998988, -0.711700, -0.153942, 0.547375, 1.328116},{0.223375, 0.466479, -0.654561, 0.549038, -0.384286, 0.724988, -0.005342, -0.619152, -1.655642},{-0.357037, 0.975246, -1.314082, -1.876585, 0.269533, 0.488916, 0.518703, 0.327121, 0.271048},{0.069322, 1.032634, 1.735610, 1.777113, 0.999772, 0.394495, -1.204739, 0.091106, 0.313935},{-1.085916, 0.304113, -0.068432, 1.184868, 0.012794, -1.602489, -0.802802, -0.058826, -0.950312},{0.852579, 1.996841, 0.618167, -0.475892, -0.936740, -0.657183, -1.611364, -0.209576, 0.889610},{-1.744210, 0.126499, -1.613281, -0.258340, -2.634301, -0.692944, 0.205406, -1.649140, -0.315315},{-0.715642, -0.822526, 1.634735, 0.667632, 0.230012, 0.729555, -0.338492, 0.576491, -1.193411},{0.910056, 0.510230, -0.194200, 0.404784, -0.312983, -1.903839, 0.320689, 0.880065, 0.472262},{-0.099256, 1.656177, -0.141429, -1.603200, -0.323099, -0.781252, -1.464200, 0.680879, -2.612153},{-0.809925, -0.195796, -1.276299, -0.259755, 0.126925, 1.394412, 0.731280, 1.092875, -0.051458},{-0.805456, 0.702107, 0.059221, -0.204989, 0.833224, -1.160910, -0.718984, -0.187568, -0.736926},{0.992373, -0.499567, 2.034003, -0.808915, -2.122912, 1.608028, 0.262947, -1.079890, 0.730572},{-0.168353, 0.544943, 1.168588, 1.103700, -0.006535, 0.272392, 1.144449, -1.298844, 0.791345},{0.797258, -0.130787, -1.195382, 1.132656, 0.785040, -0.848601, 0.417248, -0.935936, -0.757675},{-0.212776, -0.251789, -0.658834, 0.004593, 1.578799, -2.178339, -0.737351, 0.873368, 0.069753},{-1.484338, -1.184397, -1.438714, -0.606438, -2.277031, 0.121292, 0.918344, -0.070532, 0.771827},{0.058763, -1.413454, 0.076401, -0.864801, -0.970425, -0.889268, 0.560578, 1.228612, -0.339283},{2.249000, -0.902992, 0.936007, 0.271322, 0.325408, 0.934586, 0.610536, 0.508465, -0.537653},{0.207991, 0.853240, 1.075538, -0.835644, -0.035865, -0.670422, 0.468067, -2.857325, -0.140231},{1.694646, -0.032787, -0.962036, -0.516132, 0.993487, -1.456102, -1.700258, -2.254035, 1.089245},{-0.237930, -2.008438, 0.035897, -1.217830, 0.439988, 0.374136, -0.712529, 0.175358, 0.270692},{-0.291892, -0.235811, 0.176249, 0.555352, -0.643818, -0.766588, 0.905483, 0.628708, -0.907672},{-1.622154, 2.382609, -2.410437, -0.594900, -1.068846, 0.563041, -1.318001, -0.435203, -1.426894},{-1.010983, -0.832808, 0.168546, -2.263730, -1.645546, -0.206571, -0.321767, -1.001496, -0.981463},{1.529410, 0.382613, 0.354244, 0.939090, 1.602563, -0.895586, -0.616957, -0.484964, -0.037547},{-0.561943, 2.095298, -0.074588, 1.433637, 1.891291, 0.498008, 0.476642, -0.074947, -0.579277},{0.971352, -0.035025, 0.787976, -0.570488, 1.888161, -1.175896, 1.239145, -0.634213, 1.280511},{-1.827489, 0.858411, -0.337742, -0.785230, -1.772522, -0.032456, -0.047325, 1.295065, 0.249365},{-0.456220, 0.911340, -0.867637, 0.869074, 0.663751, 0.639791, -0.038705, -0.028715, 0.562768},{0.201593, 0.739048, 0.039312, 0.263451, 0.873824, -2.074708, -0.333333, -2.240851, -1.571513},{1.915591, 0.206228, 0.965635, -0.422842, -0.258883, -0.390727, 1.058453, -0.304372, -1.306399},{0.468349, -1.084722, 1.336069, -1.065655, 1.689148, 1.461042, 0.567337, 1.991360, -0.860219},{0.213399, 1.438274, -0.469645, -0.585016, -0.684798, -1.367727, 0.429513, 1.040930, 0.539725},{0.790707, 0.501889, 0.528106, 0.753125, -0.592771, -0.034210, -0.319426, -2.064659, -1.748420},{0.236602, 0.955424, -0.577294, -0.653474, 1.411273, 0.976662, -0.026732, -0.275705, 1.006502},{-0.935511, -0.073462, -0.721611, 0.580631, 0.299316, -0.263118, 2.201488, 0.657641, -0.058507},{1.738590, 0.307468, -0.538298, -1.076527, 0.046612, -0.025349, 3.157762, 1.390313, 1.645648},{-0.103781, 1.123939, -1.451762, 1.103798, -0.010214, -0.107175, 0.403577, 0.719792, 0.474462},{1.552941, -1.392361, -0.462240, 1.456160, 0.078467, -1.031735, -0.583139, 1.076648, -0.099481}};		
	}
	else{	  
	  throw art::Exception(art::errors::StdException)
	    << "Sanford-Wang MiniBooNE random numbers are only configured for Netrual Kaons";	  
	}

  }

  REGISTER_WEIGHTCALC(PrimaryHadronSanfordWangWeightCalc)
}

